# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

ANTS_MOTION_CORR_METADATA = Metadata(
    id="101179d7b402b3245503ed337e9b9c5479b1f966.boutiques",
    name="antsMotionCorr",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


AntsMotionCorrParameters = typing.TypedDict('AntsMotionCorrParameters', {
    "__STYX_TYPE__": typing.Literal["antsMotionCorr"],
    "dimensionality": typing.NotRequired[typing.Literal[2, 3] | None],
    "n_images": typing.NotRequired[int | None],
    "metric": typing.NotRequired[str | None],
    "use_fixed_reference_image": typing.NotRequired[typing.Literal[0, 1] | None],
    "use_scales_estimator": bool,
    "transform": typing.NotRequired[str | None],
    "iterations": typing.NotRequired[str | None],
    "smoothing_sigmas": typing.NotRequired[str | None],
    "shrink_factors": typing.NotRequired[str | None],
    "output": typing.NotRequired[str | None],
    "average_image": bool,
    "write_displacement": bool,
    "use_histogram_matching": typing.NotRequired[typing.Literal[0, 1] | None],
    "random_seed": typing.NotRequired[int | None],
    "interpolation": typing.NotRequired[typing.Literal["Linear", "NearestNeighbor", "BSpline", "BlackmanWindowedSinc", "CosineWindowedSinc", "WelchWindowedSinc", "HammingWindowedSinc", "LanczosWindowedSinc"] | None],
    "verbose": typing.NotRequired[typing.Literal[0, 1] | None],
})


def dyn_cargs(
    t: str,
) -> typing.Any:
    """
    Get build cargs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build cargs function.
    """
    return {
        "antsMotionCorr": ants_motion_corr_cargs,
    }.get(t)


def dyn_outputs(
    t: str,
) -> typing.Any:
    """
    Get build outputs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build outputs function.
    """
    return {
        "antsMotionCorr": ants_motion_corr_outputs,
    }.get(t)


class AntsMotionCorrOutputs(typing.NamedTuple):
    """
    Output object returned when calling `ants_motion_corr(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_transform_prefix: OutputPathType
    """The output is the transformation matrix."""
    warped_image: OutputPathType
    """The output is the warped moving image."""
    average_image_output: OutputPathType
    """The output is the averaged image of the input time series."""


def ants_motion_corr_params(
    dimensionality: typing.Literal[2, 3] | None = None,
    n_images: int | None = None,
    metric: str | None = None,
    use_fixed_reference_image: typing.Literal[0, 1] | None = None,
    use_scales_estimator: bool = False,
    transform: str | None = None,
    iterations: str | None = None,
    smoothing_sigmas: str | None = None,
    shrink_factors: str | None = None,
    output: str | None = None,
    average_image: bool = False,
    write_displacement: bool = False,
    use_histogram_matching: typing.Literal[0, 1] | None = None,
    random_seed: int | None = None,
    interpolation: typing.Literal["Linear", "NearestNeighbor", "BSpline", "BlackmanWindowedSinc", "CosineWindowedSinc", "WelchWindowedSinc", "HammingWindowedSinc", "LanczosWindowedSinc"] | None = None,
    verbose: typing.Literal[0, 1] | None = None,
) -> AntsMotionCorrParameters:
    """
    Build parameters.
    
    Args:
        dimensionality: This option forces the image to be treated as a\
            specified-dimensional image. If not specified, the program tries to\
            infer the dimensionality from the input image.
        n_images: This option sets the number of images to use to construct the\
            template image.
        metric: Metrics for registration: GC (global correlation), CC (ANTS\
            neighborhood cross correlation), MI (Mutual information), and Demons.
        use_fixed_reference_image: Use a fixed reference image to correct all\
            volumes, instead of correcting each image to the prior volume in the\
            time series.
        use_scales_estimator: Use the scale estimator to control optimization.
        transform: Several transform options are available: Affine, Rigid,\
            GaussianDisplacementField, SyN.
        iterations: Specify the number of iterations at each level.
        smoothing_sigmas: Specify the sigma for smoothing at each level.\
            Smoothing may be specified in mm units or voxels with 'AxBxCmm' or\
            'AxBxCvox'. No units implies voxels.
        shrink_factors: Specify the shrink factor for the virtual domain\
            (typically the fixed image) at each level.
        output: Specify the output transform prefix (output format is .nii.gz\
            ). Optionally, one can choose to warp the moving image to the fixed\
            space and, if the inverse transform exists, one can also output the\
            warped fixed image.
        average_image: Average the input time series image.
        write_displacement: Write the low-dimensional 3D transforms to a 4D\
            displacement field.
        use_histogram_matching: Histogram match the moving images to the\
            reference image.
        random_seed: Use a fixed seed for random number generation.
        interpolation: Several interpolation options are available in ITK. The\
            above are available (default Linear).
        verbose: Verbose output.
    Returns:
        Parameter dictionary
    """
    params = {
        "__STYXTYPE__": "antsMotionCorr",
        "use_scales_estimator": use_scales_estimator,
        "average_image": average_image,
        "write_displacement": write_displacement,
    }
    if dimensionality is not None:
        params["dimensionality"] = dimensionality
    if n_images is not None:
        params["n_images"] = n_images
    if metric is not None:
        params["metric"] = metric
    if use_fixed_reference_image is not None:
        params["use_fixed_reference_image"] = use_fixed_reference_image
    if transform is not None:
        params["transform"] = transform
    if iterations is not None:
        params["iterations"] = iterations
    if smoothing_sigmas is not None:
        params["smoothing_sigmas"] = smoothing_sigmas
    if shrink_factors is not None:
        params["shrink_factors"] = shrink_factors
    if output is not None:
        params["output"] = output
    if use_histogram_matching is not None:
        params["use_histogram_matching"] = use_histogram_matching
    if random_seed is not None:
        params["random_seed"] = random_seed
    if interpolation is not None:
        params["interpolation"] = interpolation
    if verbose is not None:
        params["verbose"] = verbose
    return params


def ants_motion_corr_cargs(
    params: AntsMotionCorrParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("antsMotionCorr")
    if params.get("dimensionality") is not None:
        cargs.extend([
            "--dimensionality",
            str(params.get("dimensionality"))
        ])
    if params.get("n_images") is not None:
        cargs.extend([
            "--n-images",
            str(params.get("n_images"))
        ])
    if params.get("metric") is not None:
        cargs.extend([
            "--metric",
            params.get("metric")
        ])
    if params.get("use_fixed_reference_image") is not None:
        cargs.extend([
            "--useFixedReferenceImage",
            str(params.get("use_fixed_reference_image"))
        ])
    if params.get("use_scales_estimator"):
        cargs.append("--useScalesEstimator")
    if params.get("transform") is not None:
        cargs.extend([
            "--transform",
            params.get("transform")
        ])
    if params.get("iterations") is not None:
        cargs.extend([
            "--iterations",
            params.get("iterations")
        ])
    if params.get("smoothing_sigmas") is not None:
        cargs.extend([
            "--smoothingSigmas",
            params.get("smoothing_sigmas")
        ])
    if params.get("shrink_factors") is not None:
        cargs.extend([
            "--shrinkFactors",
            params.get("shrink_factors")
        ])
    if params.get("output") is not None:
        cargs.extend([
            "--output",
            params.get("output")
        ])
    if params.get("average_image"):
        cargs.append("--average-image")
    if params.get("write_displacement"):
        cargs.append("--write-displacement")
    if params.get("use_histogram_matching") is not None:
        cargs.extend([
            "--use-histogram-matching",
            str(params.get("use_histogram_matching"))
        ])
    if params.get("random_seed") is not None:
        cargs.extend([
            "--random-seed",
            str(params.get("random_seed"))
        ])
    if params.get("interpolation") is not None:
        cargs.extend([
            "--interpolation",
            params.get("interpolation")
        ])
    if params.get("verbose") is not None:
        cargs.extend([
            "--verbose",
            str(params.get("verbose"))
        ])
    return cargs


def ants_motion_corr_outputs(
    params: AntsMotionCorrParameters,
    execution: Execution,
) -> AntsMotionCorrOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = AntsMotionCorrOutputs(
        root=execution.output_file("."),
        output_transform_prefix=execution.output_file("[OUTPUT_TRANSFORM_PREFIX]Affine.mat"),
        warped_image=execution.output_file("[OUTPUT_TRANSFORM_PREFIX]Warped.nii.gz"),
        average_image_output=execution.output_file("[OUTPUT_TRANSFORM_PREFIX]Average.nii.gz"),
    )
    return ret


def ants_motion_corr_execute(
    params: AntsMotionCorrParameters,
    execution: Execution,
) -> AntsMotionCorrOutputs:
    """
    ANTS Motion Correction application to perform motion correction on 4D time
    series data.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        params: The parameters.
        execution: The execution object.
    Returns:
        NamedTuple of outputs (described in `AntsMotionCorrOutputs`).
    """
    params = execution.params(params)
    cargs = ants_motion_corr_cargs(params, execution)
    ret = ants_motion_corr_outputs(params, execution)
    execution.run(cargs)
    return ret


def ants_motion_corr(
    dimensionality: typing.Literal[2, 3] | None = None,
    n_images: int | None = None,
    metric: str | None = None,
    use_fixed_reference_image: typing.Literal[0, 1] | None = None,
    use_scales_estimator: bool = False,
    transform: str | None = None,
    iterations: str | None = None,
    smoothing_sigmas: str | None = None,
    shrink_factors: str | None = None,
    output: str | None = None,
    average_image: bool = False,
    write_displacement: bool = False,
    use_histogram_matching: typing.Literal[0, 1] | None = None,
    random_seed: int | None = None,
    interpolation: typing.Literal["Linear", "NearestNeighbor", "BSpline", "BlackmanWindowedSinc", "CosineWindowedSinc", "WelchWindowedSinc", "HammingWindowedSinc", "LanczosWindowedSinc"] | None = None,
    verbose: typing.Literal[0, 1] | None = None,
    runner: Runner | None = None,
) -> AntsMotionCorrOutputs:
    """
    ANTS Motion Correction application to perform motion correction on 4D time
    series data.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        dimensionality: This option forces the image to be treated as a\
            specified-dimensional image. If not specified, the program tries to\
            infer the dimensionality from the input image.
        n_images: This option sets the number of images to use to construct the\
            template image.
        metric: Metrics for registration: GC (global correlation), CC (ANTS\
            neighborhood cross correlation), MI (Mutual information), and Demons.
        use_fixed_reference_image: Use a fixed reference image to correct all\
            volumes, instead of correcting each image to the prior volume in the\
            time series.
        use_scales_estimator: Use the scale estimator to control optimization.
        transform: Several transform options are available: Affine, Rigid,\
            GaussianDisplacementField, SyN.
        iterations: Specify the number of iterations at each level.
        smoothing_sigmas: Specify the sigma for smoothing at each level.\
            Smoothing may be specified in mm units or voxels with 'AxBxCmm' or\
            'AxBxCvox'. No units implies voxels.
        shrink_factors: Specify the shrink factor for the virtual domain\
            (typically the fixed image) at each level.
        output: Specify the output transform prefix (output format is .nii.gz\
            ). Optionally, one can choose to warp the moving image to the fixed\
            space and, if the inverse transform exists, one can also output the\
            warped fixed image.
        average_image: Average the input time series image.
        write_displacement: Write the low-dimensional 3D transforms to a 4D\
            displacement field.
        use_histogram_matching: Histogram match the moving images to the\
            reference image.
        random_seed: Use a fixed seed for random number generation.
        interpolation: Several interpolation options are available in ITK. The\
            above are available (default Linear).
        verbose: Verbose output.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AntsMotionCorrOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ANTS_MOTION_CORR_METADATA)
    params = ants_motion_corr_params(
        dimensionality=dimensionality,
        n_images=n_images,
        metric=metric,
        use_fixed_reference_image=use_fixed_reference_image,
        use_scales_estimator=use_scales_estimator,
        transform=transform,
        iterations=iterations,
        smoothing_sigmas=smoothing_sigmas,
        shrink_factors=shrink_factors,
        output=output,
        average_image=average_image,
        write_displacement=write_displacement,
        use_histogram_matching=use_histogram_matching,
        random_seed=random_seed,
        interpolation=interpolation,
        verbose=verbose,
    )
    return ants_motion_corr_execute(params, execution)


__all__ = [
    "ANTS_MOTION_CORR_METADATA",
    "AntsMotionCorrOutputs",
    "AntsMotionCorrParameters",
    "ants_motion_corr",
    "ants_motion_corr_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

RESAMPLE_IMAGE_METADATA = Metadata(
    id="243da81f65ea0a482b7b69380239da5960d94d94.boutiques",
    name="ResampleImage",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


ResampleImageParameters = typing.TypedDict('ResampleImageParameters', {
    "__STYX_TYPE__": typing.Literal["ResampleImage"],
    "image_dimension": int,
    "input_image": InputPathType,
    "output_image": str,
    "size_spacing": str,
    "interpolate_type": typing.NotRequired[typing.Literal["0", "1", "2", "3", "4"] | None],
    "pixeltype": typing.NotRequired[typing.Literal["0", "1", "2", "3", "4", "5", "6", "7"] | None],
})


def dyn_cargs(
    t: str,
) -> typing.Any:
    """
    Get build cargs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build cargs function.
    """
    return {
        "ResampleImage": resample_image_cargs,
    }.get(t)


def dyn_outputs(
    t: str,
) -> typing.Any:
    """
    Get build outputs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build outputs function.
    """
    return {
        "ResampleImage": resample_image_outputs,
    }.get(t)


class ResampleImageOutputs(typing.NamedTuple):
    """
    Output object returned when calling `resample_image(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    resampled_output_image: OutputPathType
    """The resultant image after resampling."""


def resample_image_params(
    image_dimension: int,
    input_image: InputPathType,
    output_image: str,
    size_spacing: str,
    interpolate_type: typing.Literal["0", "1", "2", "3", "4"] | None = None,
    pixeltype: typing.Literal["0", "1", "2", "3", "4", "5", "6", "7"] | None = None,
) -> ResampleImageParameters:
    """
    Build parameters.
    
    Args:
        image_dimension: Dimension of the image to be resampled.
        input_image: The image file to be resampled.
        output_image: The output image file after resampling.
        size_spacing: Resampling size and spacing specification, e.g., 'MxNxO'.
        interpolate_type: Specifies the interpolation type. 0: linear\
            (default), 1: nearest-neighbor, 2: gaussian, 3: windowedSinc, 4:\
            B-Spline.
        pixeltype: Specifies the pixel type of the output image. 0: char, 1:\
            unsigned char, 2: short, 3: unsigned short, 4: int, 5: unsigned int, 6:\
            float (default), 7: double.
    Returns:
        Parameter dictionary
    """
    params = {
        "__STYXTYPE__": "ResampleImage",
        "image_dimension": image_dimension,
        "input_image": input_image,
        "output_image": output_image,
        "size_spacing": size_spacing,
    }
    if interpolate_type is not None:
        params["interpolate_type"] = interpolate_type
    if pixeltype is not None:
        params["pixeltype"] = pixeltype
    return params


def resample_image_cargs(
    params: ResampleImageParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("ResampleImage")
    cargs.append(str(params.get("image_dimension")))
    cargs.append(execution.input_file(params.get("input_image")))
    cargs.append(params.get("output_image"))
    cargs.append(params.get("size_spacing"))
    if params.get("interpolate_type") is not None:
        cargs.append(params.get("interpolate_type"))
    if params.get("pixeltype") is not None:
        cargs.append(params.get("pixeltype"))
    return cargs


def resample_image_outputs(
    params: ResampleImageParameters,
    execution: Execution,
) -> ResampleImageOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = ResampleImageOutputs(
        root=execution.output_file("."),
        resampled_output_image=execution.output_file(params.get("output_image")),
    )
    return ret


def resample_image_execute(
    params: ResampleImageParameters,
    execution: Execution,
) -> ResampleImageOutputs:
    """
    ResampleImage is a tool used to resample images to specified sizes and spacings,
    using various interpolation methods and pixel types.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        params: The parameters.
        execution: The execution object.
    Returns:
        NamedTuple of outputs (described in `ResampleImageOutputs`).
    """
    params = execution.params(params)
    cargs = resample_image_cargs(params, execution)
    ret = resample_image_outputs(params, execution)
    execution.run(cargs)
    return ret


def resample_image(
    image_dimension: int,
    input_image: InputPathType,
    output_image: str,
    size_spacing: str,
    interpolate_type: typing.Literal["0", "1", "2", "3", "4"] | None = None,
    pixeltype: typing.Literal["0", "1", "2", "3", "4", "5", "6", "7"] | None = None,
    runner: Runner | None = None,
) -> ResampleImageOutputs:
    """
    ResampleImage is a tool used to resample images to specified sizes and spacings,
    using various interpolation methods and pixel types.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        image_dimension: Dimension of the image to be resampled.
        input_image: The image file to be resampled.
        output_image: The output image file after resampling.
        size_spacing: Resampling size and spacing specification, e.g., 'MxNxO'.
        interpolate_type: Specifies the interpolation type. 0: linear\
            (default), 1: nearest-neighbor, 2: gaussian, 3: windowedSinc, 4:\
            B-Spline.
        pixeltype: Specifies the pixel type of the output image. 0: char, 1:\
            unsigned char, 2: short, 3: unsigned short, 4: int, 5: unsigned int, 6:\
            float (default), 7: double.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ResampleImageOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(RESAMPLE_IMAGE_METADATA)
    params = resample_image_params(
        image_dimension=image_dimension,
        input_image=input_image,
        output_image=output_image,
        size_spacing=size_spacing,
        interpolate_type=interpolate_type,
        pixeltype=pixeltype,
    )
    return resample_image_execute(params, execution)


__all__ = [
    "RESAMPLE_IMAGE_METADATA",
    "ResampleImageOutputs",
    "ResampleImageParameters",
    "resample_image",
    "resample_image_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

SUPER_RESOLUTION_METADATA = Metadata(
    id="cd1212b3e1e62a6349afb70d130bc6b89439a7a0.boutiques",
    name="SuperResolution",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


SuperResolutionParameters = typing.TypedDict('SuperResolutionParameters', {
    "__STYX_TYPE__": typing.Literal["SuperResolution"],
    "image_dimension": int,
    "output_image": str,
    "domain_image": InputPathType,
    "gradient_sigma": float,
    "mesh_size": float,
    "number_of_levels": int,
    "input_image_files": list[InputPathType],
})


def dyn_cargs(
    t: str,
) -> typing.Any:
    """
    Get build cargs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build cargs function.
    """
    return {
        "SuperResolution": super_resolution_cargs,
    }.get(t)


def dyn_outputs(
    t: str,
) -> typing.Any:
    """
    Get build outputs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build outputs function.
    """
    return {
        "SuperResolution": super_resolution_outputs,
    }.get(t)


class SuperResolutionOutputs(typing.NamedTuple):
    """
    Output object returned when calling `super_resolution(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    super_resolved_image: OutputPathType
    """The output super-resolved image file."""


def super_resolution_params(
    image_dimension: int,
    output_image: str,
    domain_image: InputPathType,
    gradient_sigma: float,
    mesh_size: float,
    number_of_levels: int,
    input_image_files: list[InputPathType],
) -> SuperResolutionParameters:
    """
    Build parameters.
    
    Args:
        image_dimension: Specifies the dimensionality of the input images\
            (e.g., 2 for 2D images, 3 for 3D images).
        output_image: The file path for the output super-resolved image.
        domain_image: The domain image is used as the template space for the\
            alignment of input images.
        gradient_sigma: The sigma used for calculating the gradient magnitude\
            of input images. If negative, no weighting is applied.
        mesh_size: The size of the mesh used in fitting.
        number_of_levels: The number of resolution levels to process.
        input_image_files: List of paths to input images to be processed for\
            super resolution.
    Returns:
        Parameter dictionary
    """
    params = {
        "__STYXTYPE__": "SuperResolution",
        "image_dimension": image_dimension,
        "output_image": output_image,
        "domain_image": domain_image,
        "gradient_sigma": gradient_sigma,
        "mesh_size": mesh_size,
        "number_of_levels": number_of_levels,
        "input_image_files": input_image_files,
    }
    return params


def super_resolution_cargs(
    params: SuperResolutionParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("SuperResolution")
    cargs.append(str(params.get("image_dimension")))
    cargs.append(params.get("output_image"))
    cargs.append(execution.input_file(params.get("domain_image")))
    cargs.append(str(params.get("gradient_sigma")))
    cargs.append(str(params.get("mesh_size")))
    cargs.append(str(params.get("number_of_levels")))
    cargs.extend([execution.input_file(f) for f in params.get("input_image_files")])
    return cargs


def super_resolution_outputs(
    params: SuperResolutionParameters,
    execution: Execution,
) -> SuperResolutionOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = SuperResolutionOutputs(
        root=execution.output_file("."),
        super_resolved_image=execution.output_file(params.get("output_image")),
    )
    return ret


def super_resolution_execute(
    params: SuperResolutionParameters,
    execution: Execution,
) -> SuperResolutionOutputs:
    """
    The SuperResolution tool enhances the spatial resolution of input images. The
    'gradientSigma' parameter is used in calculating the gradient magnitude of the
    input images for weighting the voxel points during fitting. If a negative
    'gradient' sigma is specified then no weighting is used.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        params: The parameters.
        execution: The execution object.
    Returns:
        NamedTuple of outputs (described in `SuperResolutionOutputs`).
    """
    params = execution.params(params)
    cargs = super_resolution_cargs(params, execution)
    ret = super_resolution_outputs(params, execution)
    execution.run(cargs)
    return ret


def super_resolution(
    image_dimension: int,
    output_image: str,
    domain_image: InputPathType,
    gradient_sigma: float,
    mesh_size: float,
    number_of_levels: int,
    input_image_files: list[InputPathType],
    runner: Runner | None = None,
) -> SuperResolutionOutputs:
    """
    The SuperResolution tool enhances the spatial resolution of input images. The
    'gradientSigma' parameter is used in calculating the gradient magnitude of the
    input images for weighting the voxel points during fitting. If a negative
    'gradient' sigma is specified then no weighting is used.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        image_dimension: Specifies the dimensionality of the input images\
            (e.g., 2 for 2D images, 3 for 3D images).
        output_image: The file path for the output super-resolved image.
        domain_image: The domain image is used as the template space for the\
            alignment of input images.
        gradient_sigma: The sigma used for calculating the gradient magnitude\
            of input images. If negative, no weighting is applied.
        mesh_size: The size of the mesh used in fitting.
        number_of_levels: The number of resolution levels to process.
        input_image_files: List of paths to input images to be processed for\
            super resolution.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SuperResolutionOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SUPER_RESOLUTION_METADATA)
    params = super_resolution_params(
        image_dimension=image_dimension,
        output_image=output_image,
        domain_image=domain_image,
        gradient_sigma=gradient_sigma,
        mesh_size=mesh_size,
        number_of_levels=number_of_levels,
        input_image_files=input_image_files,
    )
    return super_resolution_execute(params, execution)


__all__ = [
    "SUPER_RESOLUTION_METADATA",
    "SuperResolutionOutputs",
    "SuperResolutionParameters",
    "super_resolution",
    "super_resolution_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

EXTRACT_REGION_FROM_IMAGE_BY_MASK_METADATA = Metadata(
    id="aec2f60db8048987a495410600ad2f857750da61.boutiques",
    name="ExtractRegionFromImageByMask",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


ExtractRegionFromImageByMaskParameters = typing.TypedDict('ExtractRegionFromImageByMaskParameters', {
    "__STYX_TYPE__": typing.Literal["ExtractRegionFromImageByMask"],
    "image_dimension": int,
    "input_image": InputPathType,
    "output_image": InputPathType,
    "label_mask_image": InputPathType,
    "label": typing.NotRequired[int | None],
    "pad_radius": typing.NotRequired[int | None],
})


def dyn_cargs(
    t: str,
) -> typing.Any:
    """
    Get build cargs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build cargs function.
    """
    return {
        "ExtractRegionFromImageByMask": extract_region_from_image_by_mask_cargs,
    }.get(t)


def dyn_outputs(
    t: str,
) -> typing.Any:
    """
    Get build outputs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build outputs function.
    """
    return {
    }.get(t)


class ExtractRegionFromImageByMaskOutputs(typing.NamedTuple):
    """
    Output object returned when calling `extract_region_from_image_by_mask(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def extract_region_from_image_by_mask_params(
    image_dimension: int,
    input_image: InputPathType,
    output_image: InputPathType,
    label_mask_image: InputPathType,
    label: int | None = 1,
    pad_radius: int | None = 0,
) -> ExtractRegionFromImageByMaskParameters:
    """
    Build parameters.
    
    Args:
        image_dimension: Dimension of the input image.
        input_image: The input image from which a region will be extracted.
        output_image: The output image containing the extracted region.
        label_mask_image: The label mask image used to extract the bounding\
            box.
        label: The label value used to extract the sub-region.
        pad_radius: Optional padding radius to be added around the bounding\
            box.
    Returns:
        Parameter dictionary
    """
    params = {
        "__STYXTYPE__": "ExtractRegionFromImageByMask",
        "image_dimension": image_dimension,
        "input_image": input_image,
        "output_image": output_image,
        "label_mask_image": label_mask_image,
    }
    if label is not None:
        params["label"] = label
    if pad_radius is not None:
        params["pad_radius"] = pad_radius
    return params


def extract_region_from_image_by_mask_cargs(
    params: ExtractRegionFromImageByMaskParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("ExtractRegionFromImageByMask")
    cargs.append(str(params.get("image_dimension")))
    cargs.append(execution.input_file(params.get("input_image")))
    cargs.append(execution.input_file(params.get("output_image")))
    cargs.append(execution.input_file(params.get("label_mask_image")))
    if params.get("label") is not None:
        cargs.append(str(params.get("label")))
    if params.get("pad_radius") is not None:
        cargs.append(str(params.get("pad_radius")))
    return cargs


def extract_region_from_image_by_mask_outputs(
    params: ExtractRegionFromImageByMaskParameters,
    execution: Execution,
) -> ExtractRegionFromImageByMaskOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = ExtractRegionFromImageByMaskOutputs(
        root=execution.output_file("."),
    )
    return ret


def extract_region_from_image_by_mask_execute(
    params: ExtractRegionFromImageByMaskParameters,
    execution: Execution,
) -> ExtractRegionFromImageByMaskOutputs:
    """
    Extract a sub-region from an image using the bounding box from a label image,
    with an optional padding radius.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        params: The parameters.
        execution: The execution object.
    Returns:
        NamedTuple of outputs (described in `ExtractRegionFromImageByMaskOutputs`).
    """
    params = execution.params(params)
    cargs = extract_region_from_image_by_mask_cargs(params, execution)
    ret = extract_region_from_image_by_mask_outputs(params, execution)
    execution.run(cargs)
    return ret


def extract_region_from_image_by_mask(
    image_dimension: int,
    input_image: InputPathType,
    output_image: InputPathType,
    label_mask_image: InputPathType,
    label: int | None = 1,
    pad_radius: int | None = 0,
    runner: Runner | None = None,
) -> ExtractRegionFromImageByMaskOutputs:
    """
    Extract a sub-region from an image using the bounding box from a label image,
    with an optional padding radius.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        image_dimension: Dimension of the input image.
        input_image: The input image from which a region will be extracted.
        output_image: The output image containing the extracted region.
        label_mask_image: The label mask image used to extract the bounding\
            box.
        label: The label value used to extract the sub-region.
        pad_radius: Optional padding radius to be added around the bounding\
            box.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ExtractRegionFromImageByMaskOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(EXTRACT_REGION_FROM_IMAGE_BY_MASK_METADATA)
    params = extract_region_from_image_by_mask_params(
        image_dimension=image_dimension,
        input_image=input_image,
        output_image=output_image,
        label_mask_image=label_mask_image,
        label=label,
        pad_radius=pad_radius,
    )
    return extract_region_from_image_by_mask_execute(params, execution)


__all__ = [
    "EXTRACT_REGION_FROM_IMAGE_BY_MASK_METADATA",
    "ExtractRegionFromImageByMaskOutputs",
    "ExtractRegionFromImageByMaskParameters",
    "extract_region_from_image_by_mask",
    "extract_region_from_image_by_mask_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

KELLY_KAPOWSKI_METADATA = Metadata(
    id="8cf867e1228b8566e73919051e43b36f34a80495.boutiques",
    name="KellyKapowski",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


KellyKapowskiParameters = typing.TypedDict('KellyKapowskiParameters', {
    "__STYX_TYPE__": typing.Literal["KellyKapowski"],
    "image_dimensionality": typing.NotRequired[typing.Literal[2, 3] | None],
    "segmentation_image": typing.NotRequired[InputPathType | None],
    "gray_matter_probability_image": typing.NotRequired[InputPathType | None],
    "white_matter_probability_image": typing.NotRequired[InputPathType | None],
    "convergence": typing.NotRequired[str | None],
    "thickness_prior_estimate": typing.NotRequired[float | None],
    "thickness_prior_image": typing.NotRequired[InputPathType | None],
    "gradient_step": typing.NotRequired[float | None],
    "smoothing_variance": typing.NotRequired[float | None],
    "smoothing_velocity_field_parameter": typing.NotRequired[str | None],
    "use_bspline_smoothing": typing.NotRequired[typing.Literal[0, 1] | None],
    "use_masked_smoothing": typing.NotRequired[typing.Literal[0, 1] | None],
    "time_points": typing.NotRequired[str | None],
    "restrict_deformation": typing.NotRequired[typing.Literal[0, 1] | None],
    "number_of_integration_points": typing.NotRequired[int | None],
    "maximum_number_of_invert_displacement_field_iterations": typing.NotRequired[int | None],
    "output": str,
    "verbose": typing.NotRequired[typing.Literal[0, 1] | None],
})


def dyn_cargs(
    t: str,
) -> typing.Any:
    """
    Get build cargs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build cargs function.
    """
    return {
        "KellyKapowski": kelly_kapowski_cargs,
    }.get(t)


def dyn_outputs(
    t: str,
) -> typing.Any:
    """
    Get build outputs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build outputs function.
    """
    return {
        "KellyKapowski": kelly_kapowski_outputs,
    }.get(t)


class KellyKapowskiOutputs(typing.NamedTuple):
    """
    Output object returned when calling `kelly_kapowski(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    thickness_map: OutputPathType
    """The output is the thickness map defined in the segmented gray matter."""


def kelly_kapowski_params(
    output: str,
    image_dimensionality: typing.Literal[2, 3] | None = None,
    segmentation_image: InputPathType | None = None,
    gray_matter_probability_image: InputPathType | None = None,
    white_matter_probability_image: InputPathType | None = None,
    convergence: str | None = None,
    thickness_prior_estimate: float | None = None,
    thickness_prior_image: InputPathType | None = None,
    gradient_step: float | None = None,
    smoothing_variance: float | None = None,
    smoothing_velocity_field_parameter: str | None = None,
    use_bspline_smoothing: typing.Literal[0, 1] | None = None,
    use_masked_smoothing: typing.Literal[0, 1] | None = None,
    time_points: str | None = None,
    restrict_deformation: typing.Literal[0, 1] | None = None,
    number_of_integration_points: int | None = None,
    maximum_number_of_invert_displacement_field_iterations: int | None = None,
    verbose: typing.Literal[0, 1] | None = None,
) -> KellyKapowskiParameters:
    """
    Build parameters.
    
    Args:
        output: The output consists of a thickness map defined in the segmented\
            gray matter.
        image_dimensionality: This option forces the image to be treated as a\
            specified-dimensional image. If not specified, DiReCT tries to infer\
            the dimensionality from the input image.
        segmentation_image: A segmentation image must be supplied labeling the\
            gray and white matters. Default values = 2 and 3, respectively.
        gray_matter_probability_image: In addition to the segmentation image, a\
            gray matter probability image can be used. If no such image is\
            supplied, one is created using the segmentation image and a variance of\
            1.0 mm.
        white_matter_probability_image: In addition to the segmentation image,\
            a white matter probability image can be used. If no such image is\
            supplied, one is created using the segmentation image and a variance of\
            1.0 mm.
        convergence: Convergence is determined by fitting a line to the\
            normalized energy profile of the last N iterations (where N is\
            specified by the window size) and determining the slope which is then\
            compared with the convergence threshold.
        thickness_prior_estimate: Provides a prior constraint on the final\
            thickness measurement. Default = 10 mm.
        thickness_prior_image: An image containing spatially varying prior\
            thickness values.
        gradient_step: Gradient step size for the optimization. Default =\
            0.025.
        smoothing_variance: Defines the Gaussian smoothing of the hit and total\
            images. Default = 1.0 mm.
        smoothing_velocity_field_parameter: Defines the Gaussian smoothing of\
            the velocity field (default = 1.5 voxels). If the b-spline smoothing\
            option is chosen, then this defines the isotropic mesh spacing for the\
            smoothing spline (default = 15 mm).
        use_bspline_smoothing: Sets the option for B-spline smoothing of the\
            velocity field. Default = false.
        use_masked_smoothing: Sets the option for masked-based smoothing of the\
            velocity field. Default = false.
        time_points: Time points for irregularly spaced time samples and\
            time-variance with which to compute distance metric.
        restrict_deformation: Restrict the last dimension's deformation. Meant\
            for use with multiple time points. Default = false.
        number_of_integration_points: Number of compositions of the\
            diffeomorphism per iteration. Default = 10.
        maximum_number_of_invert_displacement_field_iterations: Maximum number\
            of iterations for estimating the invert displacement field. Default =\
            20.
        verbose: Verbose output.
    Returns:
        Parameter dictionary
    """
    params = {
        "__STYXTYPE__": "KellyKapowski",
        "output": output,
    }
    if image_dimensionality is not None:
        params["image_dimensionality"] = image_dimensionality
    if segmentation_image is not None:
        params["segmentation_image"] = segmentation_image
    if gray_matter_probability_image is not None:
        params["gray_matter_probability_image"] = gray_matter_probability_image
    if white_matter_probability_image is not None:
        params["white_matter_probability_image"] = white_matter_probability_image
    if convergence is not None:
        params["convergence"] = convergence
    if thickness_prior_estimate is not None:
        params["thickness_prior_estimate"] = thickness_prior_estimate
    if thickness_prior_image is not None:
        params["thickness_prior_image"] = thickness_prior_image
    if gradient_step is not None:
        params["gradient_step"] = gradient_step
    if smoothing_variance is not None:
        params["smoothing_variance"] = smoothing_variance
    if smoothing_velocity_field_parameter is not None:
        params["smoothing_velocity_field_parameter"] = smoothing_velocity_field_parameter
    if use_bspline_smoothing is not None:
        params["use_bspline_smoothing"] = use_bspline_smoothing
    if use_masked_smoothing is not None:
        params["use_masked_smoothing"] = use_masked_smoothing
    if time_points is not None:
        params["time_points"] = time_points
    if restrict_deformation is not None:
        params["restrict_deformation"] = restrict_deformation
    if number_of_integration_points is not None:
        params["number_of_integration_points"] = number_of_integration_points
    if maximum_number_of_invert_displacement_field_iterations is not None:
        params["maximum_number_of_invert_displacement_field_iterations"] = maximum_number_of_invert_displacement_field_iterations
    if verbose is not None:
        params["verbose"] = verbose
    return params


def kelly_kapowski_cargs(
    params: KellyKapowskiParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("KellyKapowski")
    if params.get("image_dimensionality") is not None:
        cargs.extend([
            "--image-dimensionality",
            str(params.get("image_dimensionality"))
        ])
    if params.get("segmentation_image") is not None:
        cargs.extend([
            "--segmentation-image",
            execution.input_file(params.get("segmentation_image"))
        ])
    if params.get("gray_matter_probability_image") is not None:
        cargs.extend([
            "--gray-matter-probability-image",
            execution.input_file(params.get("gray_matter_probability_image"))
        ])
    if params.get("white_matter_probability_image") is not None:
        cargs.extend([
            "--white-matter-probability-image",
            execution.input_file(params.get("white_matter_probability_image"))
        ])
    if params.get("convergence") is not None:
        cargs.extend([
            "--convergence",
            params.get("convergence")
        ])
    if params.get("thickness_prior_estimate") is not None:
        cargs.extend([
            "--thickness-prior-estimate",
            str(params.get("thickness_prior_estimate"))
        ])
    if params.get("thickness_prior_image") is not None:
        cargs.extend([
            "--thickness-prior-image",
            execution.input_file(params.get("thickness_prior_image"))
        ])
    if params.get("gradient_step") is not None:
        cargs.extend([
            "--gradient-step",
            str(params.get("gradient_step"))
        ])
    if params.get("smoothing_variance") is not None:
        cargs.extend([
            "--smoothing-variance",
            str(params.get("smoothing_variance"))
        ])
    if params.get("smoothing_velocity_field_parameter") is not None:
        cargs.extend([
            "--smoothing-velocity-field-parameter",
            params.get("smoothing_velocity_field_parameter")
        ])
    if params.get("use_bspline_smoothing") is not None:
        cargs.extend([
            "--use-bspline-smoothing",
            str(params.get("use_bspline_smoothing"))
        ])
    if params.get("use_masked_smoothing") is not None:
        cargs.extend([
            "--use-masked-smoothing",
            str(params.get("use_masked_smoothing"))
        ])
    if params.get("time_points") is not None:
        cargs.extend([
            "--time-points",
            params.get("time_points")
        ])
    if params.get("restrict_deformation") is not None:
        cargs.extend([
            "--restrict-deformation",
            str(params.get("restrict_deformation"))
        ])
    if params.get("number_of_integration_points") is not None:
        cargs.extend([
            "--number-of-integration-points",
            str(params.get("number_of_integration_points"))
        ])
    if params.get("maximum_number_of_invert_displacement_field_iterations") is not None:
        cargs.extend([
            "--maximum-number-of-invert-displacement-field-iterations",
            str(params.get("maximum_number_of_invert_displacement_field_iterations"))
        ])
    cargs.extend([
        "--output",
        params.get("output")
    ])
    if params.get("verbose") is not None:
        cargs.extend([
            "--verbose",
            str(params.get("verbose"))
        ])
    return cargs


def kelly_kapowski_outputs(
    params: KellyKapowskiParameters,
    execution: Execution,
) -> KellyKapowskiOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = KellyKapowskiOutputs(
        root=execution.output_file("."),
        thickness_map=execution.output_file(params.get("output")),
    )
    return ret


def kelly_kapowski_execute(
    params: KellyKapowskiParameters,
    execution: Execution,
) -> KellyKapowskiOutputs:
    """
    DiReCT is a registration based estimate of cortical thickness. It was published
    in S. R. Das, B. B. Avants, M. Grossman, and J. C. Gee, Registration based
    cortical thickness measurement, Neuroimage 2009, 45:867--879.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        params: The parameters.
        execution: The execution object.
    Returns:
        NamedTuple of outputs (described in `KellyKapowskiOutputs`).
    """
    params = execution.params(params)
    cargs = kelly_kapowski_cargs(params, execution)
    ret = kelly_kapowski_outputs(params, execution)
    execution.run(cargs)
    return ret


def kelly_kapowski(
    output: str,
    image_dimensionality: typing.Literal[2, 3] | None = None,
    segmentation_image: InputPathType | None = None,
    gray_matter_probability_image: InputPathType | None = None,
    white_matter_probability_image: InputPathType | None = None,
    convergence: str | None = None,
    thickness_prior_estimate: float | None = None,
    thickness_prior_image: InputPathType | None = None,
    gradient_step: float | None = None,
    smoothing_variance: float | None = None,
    smoothing_velocity_field_parameter: str | None = None,
    use_bspline_smoothing: typing.Literal[0, 1] | None = None,
    use_masked_smoothing: typing.Literal[0, 1] | None = None,
    time_points: str | None = None,
    restrict_deformation: typing.Literal[0, 1] | None = None,
    number_of_integration_points: int | None = None,
    maximum_number_of_invert_displacement_field_iterations: int | None = None,
    verbose: typing.Literal[0, 1] | None = None,
    runner: Runner | None = None,
) -> KellyKapowskiOutputs:
    """
    DiReCT is a registration based estimate of cortical thickness. It was published
    in S. R. Das, B. B. Avants, M. Grossman, and J. C. Gee, Registration based
    cortical thickness measurement, Neuroimage 2009, 45:867--879.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        output: The output consists of a thickness map defined in the segmented\
            gray matter.
        image_dimensionality: This option forces the image to be treated as a\
            specified-dimensional image. If not specified, DiReCT tries to infer\
            the dimensionality from the input image.
        segmentation_image: A segmentation image must be supplied labeling the\
            gray and white matters. Default values = 2 and 3, respectively.
        gray_matter_probability_image: In addition to the segmentation image, a\
            gray matter probability image can be used. If no such image is\
            supplied, one is created using the segmentation image and a variance of\
            1.0 mm.
        white_matter_probability_image: In addition to the segmentation image,\
            a white matter probability image can be used. If no such image is\
            supplied, one is created using the segmentation image and a variance of\
            1.0 mm.
        convergence: Convergence is determined by fitting a line to the\
            normalized energy profile of the last N iterations (where N is\
            specified by the window size) and determining the slope which is then\
            compared with the convergence threshold.
        thickness_prior_estimate: Provides a prior constraint on the final\
            thickness measurement. Default = 10 mm.
        thickness_prior_image: An image containing spatially varying prior\
            thickness values.
        gradient_step: Gradient step size for the optimization. Default =\
            0.025.
        smoothing_variance: Defines the Gaussian smoothing of the hit and total\
            images. Default = 1.0 mm.
        smoothing_velocity_field_parameter: Defines the Gaussian smoothing of\
            the velocity field (default = 1.5 voxels). If the b-spline smoothing\
            option is chosen, then this defines the isotropic mesh spacing for the\
            smoothing spline (default = 15 mm).
        use_bspline_smoothing: Sets the option for B-spline smoothing of the\
            velocity field. Default = false.
        use_masked_smoothing: Sets the option for masked-based smoothing of the\
            velocity field. Default = false.
        time_points: Time points for irregularly spaced time samples and\
            time-variance with which to compute distance metric.
        restrict_deformation: Restrict the last dimension's deformation. Meant\
            for use with multiple time points. Default = false.
        number_of_integration_points: Number of compositions of the\
            diffeomorphism per iteration. Default = 10.
        maximum_number_of_invert_displacement_field_iterations: Maximum number\
            of iterations for estimating the invert displacement field. Default =\
            20.
        verbose: Verbose output.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `KellyKapowskiOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(KELLY_KAPOWSKI_METADATA)
    params = kelly_kapowski_params(
        image_dimensionality=image_dimensionality,
        segmentation_image=segmentation_image,
        gray_matter_probability_image=gray_matter_probability_image,
        white_matter_probability_image=white_matter_probability_image,
        convergence=convergence,
        thickness_prior_estimate=thickness_prior_estimate,
        thickness_prior_image=thickness_prior_image,
        gradient_step=gradient_step,
        smoothing_variance=smoothing_variance,
        smoothing_velocity_field_parameter=smoothing_velocity_field_parameter,
        use_bspline_smoothing=use_bspline_smoothing,
        use_masked_smoothing=use_masked_smoothing,
        time_points=time_points,
        restrict_deformation=restrict_deformation,
        number_of_integration_points=number_of_integration_points,
        maximum_number_of_invert_displacement_field_iterations=maximum_number_of_invert_displacement_field_iterations,
        output=output,
        verbose=verbose,
    )
    return kelly_kapowski_execute(params, execution)


__all__ = [
    "KELLY_KAPOWSKI_METADATA",
    "KellyKapowskiOutputs",
    "KellyKapowskiParameters",
    "kelly_kapowski",
    "kelly_kapowski_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

ANTSJACOBIAN_METADATA = Metadata(
    id="4c1495ce17166625b172b3fbe727bd30b17f079f.boutiques",
    name="ANTSJacobian",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


AntsjacobianParameters = typing.TypedDict('AntsjacobianParameters', {
    "__STYX_TYPE__": typing.Literal["ANTSJacobian"],
    "imagedim": int,
    "gwarp": InputPathType,
    "outfile": str,
    "uselog": int,
    "maskfn": InputPathType,
    "normbytotalbool": int,
    "projectionvector": typing.NotRequired[str | None],
})


def dyn_cargs(
    t: str,
) -> typing.Any:
    """
    Get build cargs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build cargs function.
    """
    return {
        "ANTSJacobian": antsjacobian_cargs,
    }.get(t)


def dyn_outputs(
    t: str,
) -> typing.Any:
    """
    Get build outputs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build outputs function.
    """
    return {
        "ANTSJacobian": antsjacobian_outputs,
    }.get(t)


class AntsjacobianOutputs(typing.NamedTuple):
    """
    Output object returned when calling `antsjacobian(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    jacobian_output: OutputPathType
    """Output file containing the Jacobian determinant information."""


def antsjacobian_params(
    imagedim: int,
    gwarp: InputPathType,
    outfile: str,
    uselog: int,
    maskfn: InputPathType,
    normbytotalbool: int,
    projectionvector: str | None = None,
) -> AntsjacobianParameters:
    """
    Build parameters.
    
    Args:
        imagedim: The dimensionality of the input image.
        gwarp: The input warp image.
        outfile: The prefix for the output files.
        uselog: Whether to use logarithm in computation.
        maskfn: Mask file used in the computation.
        normbytotalbool: Normalize the Jacobian by the total in the mask. Use\
            this to adjust for head size.
        projectionvector: Projects the warp along the specified direction. Do\
            not add this option if no projection is desired.
    Returns:
        Parameter dictionary
    """
    params = {
        "__STYXTYPE__": "ANTSJacobian",
        "imagedim": imagedim,
        "gwarp": gwarp,
        "outfile": outfile,
        "uselog": uselog,
        "maskfn": maskfn,
        "normbytotalbool": normbytotalbool,
    }
    if projectionvector is not None:
        params["projectionvector"] = projectionvector
    return params


def antsjacobian_cargs(
    params: AntsjacobianParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("ANTSJacobian")
    cargs.append(str(params.get("imagedim")))
    cargs.append(execution.input_file(params.get("gwarp")))
    cargs.append(params.get("outfile"))
    cargs.append(str(params.get("uselog")))
    cargs.append(execution.input_file(params.get("maskfn")))
    cargs.append(str(params.get("normbytotalbool")))
    if params.get("projectionvector") is not None:
        cargs.append(params.get("projectionvector"))
    return cargs


def antsjacobian_outputs(
    params: AntsjacobianParameters,
    execution: Execution,
) -> AntsjacobianOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = AntsjacobianOutputs(
        root=execution.output_file("."),
        jacobian_output=execution.output_file(params.get("outfile") + "Jacobian.nii.gz"),
    )
    return ret


def antsjacobian_execute(
    params: AntsjacobianParameters,
    execution: Execution,
) -> AntsjacobianOutputs:
    """
    Calculate the Jacobian determinant of a transformation using ANTs. WARNING:
    ANTSJacobian may not be working correctly; see CreateJacobianDeterminantImage
    for an alternative method.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        params: The parameters.
        execution: The execution object.
    Returns:
        NamedTuple of outputs (described in `AntsjacobianOutputs`).
    """
    params = execution.params(params)
    cargs = antsjacobian_cargs(params, execution)
    ret = antsjacobian_outputs(params, execution)
    execution.run(cargs)
    return ret


def antsjacobian(
    imagedim: int,
    gwarp: InputPathType,
    outfile: str,
    uselog: int,
    maskfn: InputPathType,
    normbytotalbool: int,
    projectionvector: str | None = None,
    runner: Runner | None = None,
) -> AntsjacobianOutputs:
    """
    Calculate the Jacobian determinant of a transformation using ANTs. WARNING:
    ANTSJacobian may not be working correctly; see CreateJacobianDeterminantImage
    for an alternative method.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        imagedim: The dimensionality of the input image.
        gwarp: The input warp image.
        outfile: The prefix for the output files.
        uselog: Whether to use logarithm in computation.
        maskfn: Mask file used in the computation.
        normbytotalbool: Normalize the Jacobian by the total in the mask. Use\
            this to adjust for head size.
        projectionvector: Projects the warp along the specified direction. Do\
            not add this option if no projection is desired.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AntsjacobianOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ANTSJACOBIAN_METADATA)
    params = antsjacobian_params(
        imagedim=imagedim,
        gwarp=gwarp,
        outfile=outfile,
        uselog=uselog,
        maskfn=maskfn,
        normbytotalbool=normbytotalbool,
        projectionvector=projectionvector,
    )
    return antsjacobian_execute(params, execution)


__all__ = [
    "ANTSJACOBIAN_METADATA",
    "AntsjacobianOutputs",
    "AntsjacobianParameters",
    "antsjacobian",
    "antsjacobian_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

ANTS_MOTION_CORR_DIFFUSION_DIRECTION_METADATA = Metadata(
    id="3f81491f1faf2e11f2fe0e69121f28544825a2d4.boutiques",
    name="antsMotionCorrDiffusionDirection",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


AntsMotionCorrDiffusionDirectionParameters = typing.TypedDict('AntsMotionCorrDiffusionDirectionParameters', {
    "__STYX_TYPE__": typing.Literal["antsMotionCorrDiffusionDirection"],
    "scheme": InputPathType,
    "bvec": InputPathType,
    "physical": InputPathType,
    "moco": InputPathType,
    "output": str,
})


def dyn_cargs(
    t: str,
) -> typing.Any:
    """
    Get build cargs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build cargs function.
    """
    return {
        "antsMotionCorrDiffusionDirection": ants_motion_corr_diffusion_direction_cargs,
    }.get(t)


def dyn_outputs(
    t: str,
) -> typing.Any:
    """
    Get build outputs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build outputs function.
    """
    return {
        "antsMotionCorrDiffusionDirection": ants_motion_corr_diffusion_direction_outputs,
    }.get(t)


class AntsMotionCorrDiffusionDirectionOutputs(typing.NamedTuple):
    """
    Output object returned when calling `ants_motion_corr_diffusion_direction(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    corrected_scheme: OutputPathType
    """The output file for corrected diffusion directions."""


def ants_motion_corr_diffusion_direction_params(
    scheme: InputPathType,
    bvec: InputPathType,
    physical: InputPathType,
    moco: InputPathType,
    output: str,
) -> AntsMotionCorrDiffusionDirectionParameters:
    """
    Build parameters.
    
    Args:
        scheme: Camino scheme file specify acquisition parameters.
        bvec: bvec image specifying diffusion directions.
        physical: 3D image in dwi space.
        moco: Motion correction parameters from antsMotionCorr.
        output: Specify the output file for corrected directions.
    Returns:
        Parameter dictionary
    """
    params = {
        "__STYXTYPE__": "antsMotionCorrDiffusionDirection",
        "scheme": scheme,
        "bvec": bvec,
        "physical": physical,
        "moco": moco,
        "output": output,
    }
    return params


def ants_motion_corr_diffusion_direction_cargs(
    params: AntsMotionCorrDiffusionDirectionParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("antsMotionCorrDiffusionDirection")
    cargs.extend([
        "-s",
        execution.input_file(params.get("scheme"))
    ])
    cargs.extend([
        "-b",
        execution.input_file(params.get("bvec"))
    ])
    cargs.extend([
        "-p",
        execution.input_file(params.get("physical"))
    ])
    cargs.extend([
        "-m",
        execution.input_file(params.get("moco"))
    ])
    cargs.extend([
        "-o",
        params.get("output")
    ])
    return cargs


def ants_motion_corr_diffusion_direction_outputs(
    params: AntsMotionCorrDiffusionDirectionParameters,
    execution: Execution,
) -> AntsMotionCorrDiffusionDirectionOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = AntsMotionCorrDiffusionDirectionOutputs(
        root=execution.output_file("."),
        corrected_scheme=execution.output_file(params.get("output")),
    )
    return ret


def ants_motion_corr_diffusion_direction_execute(
    params: AntsMotionCorrDiffusionDirectionParameters,
    execution: Execution,
) -> AntsMotionCorrDiffusionDirectionOutputs:
    """
    This tool adjusts the diffusion scheme for motion correction.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        params: The parameters.
        execution: The execution object.
    Returns:
        NamedTuple of outputs (described in `AntsMotionCorrDiffusionDirectionOutputs`).
    """
    params = execution.params(params)
    cargs = ants_motion_corr_diffusion_direction_cargs(params, execution)
    ret = ants_motion_corr_diffusion_direction_outputs(params, execution)
    execution.run(cargs)
    return ret


def ants_motion_corr_diffusion_direction(
    scheme: InputPathType,
    bvec: InputPathType,
    physical: InputPathType,
    moco: InputPathType,
    output: str,
    runner: Runner | None = None,
) -> AntsMotionCorrDiffusionDirectionOutputs:
    """
    This tool adjusts the diffusion scheme for motion correction.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        scheme: Camino scheme file specify acquisition parameters.
        bvec: bvec image specifying diffusion directions.
        physical: 3D image in dwi space.
        moco: Motion correction parameters from antsMotionCorr.
        output: Specify the output file for corrected directions.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AntsMotionCorrDiffusionDirectionOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ANTS_MOTION_CORR_DIFFUSION_DIRECTION_METADATA)
    params = ants_motion_corr_diffusion_direction_params(
        scheme=scheme,
        bvec=bvec,
        physical=physical,
        moco=moco,
        output=output,
    )
    return ants_motion_corr_diffusion_direction_execute(params, execution)


__all__ = [
    "ANTS_MOTION_CORR_DIFFUSION_DIRECTION_METADATA",
    "AntsMotionCorrDiffusionDirectionOutputs",
    "AntsMotionCorrDiffusionDirectionParameters",
    "ants_motion_corr_diffusion_direction",
    "ants_motion_corr_diffusion_direction_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

ANTS_LANDMARK_BASED_TRANSFORM_INITIALIZER_METADATA = Metadata(
    id="0a1f0f529ca0b132289382b0bfa307fd1e5cda95.boutiques",
    name="antsLandmarkBasedTransformInitializer",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


AntsLandmarkBasedTransformInitializerParameters = typing.TypedDict('AntsLandmarkBasedTransformInitializerParameters', {
    "__STYX_TYPE__": typing.Literal["antsLandmarkBasedTransformInitializer"],
    "dimension": int,
    "fixed_image": InputPathType,
    "moving_image": InputPathType,
    "transform_type": typing.Literal["rigid", "affine", "bspline"],
    "output_transform": str,
    "mesh_size": typing.NotRequired[str | None],
    "number_of_levels": typing.NotRequired[int | None],
    "order": typing.NotRequired[int | None],
    "enforce_stationary_boundaries": typing.NotRequired[typing.Literal[0, 1] | None],
    "landmark_weights": typing.NotRequired[InputPathType | None],
})


def dyn_cargs(
    t: str,
) -> typing.Any:
    """
    Get build cargs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build cargs function.
    """
    return {
        "antsLandmarkBasedTransformInitializer": ants_landmark_based_transform_initializer_cargs,
    }.get(t)


def dyn_outputs(
    t: str,
) -> typing.Any:
    """
    Get build outputs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build outputs function.
    """
    return {
        "antsLandmarkBasedTransformInitializer": ants_landmark_based_transform_initializer_outputs,
    }.get(t)


class AntsLandmarkBasedTransformInitializerOutputs(typing.NamedTuple):
    """
    Output object returned when calling `ants_landmark_based_transform_initializer(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_transform: OutputPathType
    """The output file containing the initialized transform."""


def ants_landmark_based_transform_initializer_params(
    dimension: int,
    fixed_image: InputPathType,
    moving_image: InputPathType,
    transform_type: typing.Literal["rigid", "affine", "bspline"],
    output_transform: str,
    mesh_size: str | None = None,
    number_of_levels: int | None = None,
    order: int | None = None,
    enforce_stationary_boundaries: typing.Literal[0, 1] | None = None,
    landmark_weights: InputPathType | None = None,
) -> AntsLandmarkBasedTransformInitializerParameters:
    """
    Build parameters.
    
    Args:
        dimension: The dimensionality of the registration problem (e.g., 2 for\
            2D, 3 for 3D).
        fixed_image: The fixed image in the registration process.
        moving_image: The moving image in the registration process.
        transform_type: The type of transform to initialize. Options are\
            'rigid', 'affine', or 'bspline'.
        output_transform: The output transform file that will be created.
        mesh_size: The mesh size for the B-spline transform, specified as\
            'meshSize[0]xmeshSize[1]x...'. Default is '1x1x1'.
        number_of_levels: Number of levels for multi-resolution fitting.\
            Default is 4.
        order: The polynomial order of the B-spline transform. Default is 3.
        enforce_stationary_boundaries: Enforces stationary boundaries for the\
            B-spline transform. Default is 1 (true).
        landmark_weights: File containing landmark weights. Each row is either\
            'label,labelWeight' or 'labelWeight'.
    Returns:
        Parameter dictionary
    """
    params = {
        "__STYXTYPE__": "antsLandmarkBasedTransformInitializer",
        "dimension": dimension,
        "fixed_image": fixed_image,
        "moving_image": moving_image,
        "transform_type": transform_type,
        "output_transform": output_transform,
    }
    if mesh_size is not None:
        params["mesh_size"] = mesh_size
    if number_of_levels is not None:
        params["number_of_levels"] = number_of_levels
    if order is not None:
        params["order"] = order
    if enforce_stationary_boundaries is not None:
        params["enforce_stationary_boundaries"] = enforce_stationary_boundaries
    if landmark_weights is not None:
        params["landmark_weights"] = landmark_weights
    return params


def ants_landmark_based_transform_initializer_cargs(
    params: AntsLandmarkBasedTransformInitializerParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("antsLandmarkBasedTransformInitializer")
    cargs.append(str(params.get("dimension")))
    cargs.append(execution.input_file(params.get("fixed_image")))
    cargs.append(execution.input_file(params.get("moving_image")))
    cargs.append(params.get("transform_type"))
    cargs.append(params.get("output_transform"))
    if params.get("mesh_size") is not None:
        cargs.append(params.get("mesh_size"))
    if params.get("number_of_levels") is not None:
        cargs.append(str(params.get("number_of_levels")))
    if params.get("order") is not None:
        cargs.append(str(params.get("order")))
    if params.get("enforce_stationary_boundaries") is not None:
        cargs.append(str(params.get("enforce_stationary_boundaries")))
    if params.get("landmark_weights") is not None:
        cargs.append(execution.input_file(params.get("landmark_weights")))
    return cargs


def ants_landmark_based_transform_initializer_outputs(
    params: AntsLandmarkBasedTransformInitializerParameters,
    execution: Execution,
) -> AntsLandmarkBasedTransformInitializerOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = AntsLandmarkBasedTransformInitializerOutputs(
        root=execution.output_file("."),
        output_transform=execution.output_file(params.get("output_transform")),
    )
    return ret


def ants_landmark_based_transform_initializer_execute(
    params: AntsLandmarkBasedTransformInitializerParameters,
    execution: Execution,
) -> AntsLandmarkBasedTransformInitializerOutputs:
    """
    This tool initializes a transform between two images based on corresponding
    landmarks.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        params: The parameters.
        execution: The execution object.
    Returns:
        NamedTuple of outputs (described in `AntsLandmarkBasedTransformInitializerOutputs`).
    """
    params = execution.params(params)
    cargs = ants_landmark_based_transform_initializer_cargs(params, execution)
    ret = ants_landmark_based_transform_initializer_outputs(params, execution)
    execution.run(cargs)
    return ret


def ants_landmark_based_transform_initializer(
    dimension: int,
    fixed_image: InputPathType,
    moving_image: InputPathType,
    transform_type: typing.Literal["rigid", "affine", "bspline"],
    output_transform: str,
    mesh_size: str | None = None,
    number_of_levels: int | None = None,
    order: int | None = None,
    enforce_stationary_boundaries: typing.Literal[0, 1] | None = None,
    landmark_weights: InputPathType | None = None,
    runner: Runner | None = None,
) -> AntsLandmarkBasedTransformInitializerOutputs:
    """
    This tool initializes a transform between two images based on corresponding
    landmarks.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        dimension: The dimensionality of the registration problem (e.g., 2 for\
            2D, 3 for 3D).
        fixed_image: The fixed image in the registration process.
        moving_image: The moving image in the registration process.
        transform_type: The type of transform to initialize. Options are\
            'rigid', 'affine', or 'bspline'.
        output_transform: The output transform file that will be created.
        mesh_size: The mesh size for the B-spline transform, specified as\
            'meshSize[0]xmeshSize[1]x...'. Default is '1x1x1'.
        number_of_levels: Number of levels for multi-resolution fitting.\
            Default is 4.
        order: The polynomial order of the B-spline transform. Default is 3.
        enforce_stationary_boundaries: Enforces stationary boundaries for the\
            B-spline transform. Default is 1 (true).
        landmark_weights: File containing landmark weights. Each row is either\
            'label,labelWeight' or 'labelWeight'.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AntsLandmarkBasedTransformInitializerOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ANTS_LANDMARK_BASED_TRANSFORM_INITIALIZER_METADATA)
    params = ants_landmark_based_transform_initializer_params(
        dimension=dimension,
        fixed_image=fixed_image,
        moving_image=moving_image,
        transform_type=transform_type,
        output_transform=output_transform,
        mesh_size=mesh_size,
        number_of_levels=number_of_levels,
        order=order,
        enforce_stationary_boundaries=enforce_stationary_boundaries,
        landmark_weights=landmark_weights,
    )
    return ants_landmark_based_transform_initializer_execute(params, execution)


__all__ = [
    "ANTS_LANDMARK_BASED_TRANSFORM_INITIALIZER_METADATA",
    "AntsLandmarkBasedTransformInitializerOutputs",
    "AntsLandmarkBasedTransformInitializerParameters",
    "ants_landmark_based_transform_initializer",
    "ants_landmark_based_transform_initializer_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

SURFACE_CURVATURE_METADATA = Metadata(
    id="47bd42166388900cd8ce701c63aa9324fd46a426.boutiques",
    name="SurfaceCurvature",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


SurfaceCurvatureParameters = typing.TypedDict('SurfaceCurvatureParameters', {
    "__STYX_TYPE__": typing.Literal["SurfaceCurvature"],
    "filename_in": InputPathType,
    "filename_out": str,
    "sigma": float,
    "option": float,
})


def dyn_cargs(
    t: str,
) -> typing.Any:
    """
    Get build cargs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build cargs function.
    """
    return {
        "SurfaceCurvature": surface_curvature_cargs,
    }.get(t)


def dyn_outputs(
    t: str,
) -> typing.Any:
    """
    Get build outputs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build outputs function.
    """
    return {
        "SurfaceCurvature": surface_curvature_outputs,
    }.get(t)


class SurfaceCurvatureOutputs(typing.NamedTuple):
    """
    Output object returned when calling `surface_curvature(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_image: OutputPathType
    """The processed image file."""


def surface_curvature_params(
    filename_in: InputPathType,
    filename_out: str,
    sigma: float,
    option: float,
) -> SurfaceCurvatureParameters:
    """
    Build parameters.
    
    Args:
        filename_in: The input image file in .nii format.
        filename_out: The output image file in .nii format.
        sigma: The sigma value for analysis.
        option: The operation mode: 0 for mean curvature, 5 for surface\
            characterization, 6 for Gaussian curvature, and 7 for surface area.
    Returns:
        Parameter dictionary
    """
    params = {
        "__STYXTYPE__": "SurfaceCurvature",
        "filename_in": filename_in,
        "filename_out": filename_out,
        "sigma": sigma,
        "option": option,
    }
    return params


def surface_curvature_cargs(
    params: SurfaceCurvatureParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("SurfaceCurvature" + execution.input_file(params.get("filename_in")) + params.get("filename_out") + str(params.get("sigma")) + str(params.get("option")))
    return cargs


def surface_curvature_outputs(
    params: SurfaceCurvatureParameters,
    execution: Execution,
) -> SurfaceCurvatureOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = SurfaceCurvatureOutputs(
        root=execution.output_file("."),
        output_image=execution.output_file(params.get("filename_out")),
    )
    return ret


def surface_curvature_execute(
    params: SurfaceCurvatureParameters,
    execution: Execution,
) -> SurfaceCurvatureOutputs:
    """
    The Shape Operator for Differential Analysis of Images. It can operate on binary
    or gray scale images with various modes to see different effects.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        params: The parameters.
        execution: The execution object.
    Returns:
        NamedTuple of outputs (described in `SurfaceCurvatureOutputs`).
    """
    params = execution.params(params)
    cargs = surface_curvature_cargs(params, execution)
    ret = surface_curvature_outputs(params, execution)
    execution.run(cargs)
    return ret


def surface_curvature(
    filename_in: InputPathType,
    filename_out: str,
    sigma: float,
    option: float,
    runner: Runner | None = None,
) -> SurfaceCurvatureOutputs:
    """
    The Shape Operator for Differential Analysis of Images. It can operate on binary
    or gray scale images with various modes to see different effects.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        filename_in: The input image file in .nii format.
        filename_out: The output image file in .nii format.
        sigma: The sigma value for analysis.
        option: The operation mode: 0 for mean curvature, 5 for surface\
            characterization, 6 for Gaussian curvature, and 7 for surface area.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceCurvatureOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURFACE_CURVATURE_METADATA)
    params = surface_curvature_params(
        filename_in=filename_in,
        filename_out=filename_out,
        sigma=sigma,
        option=option,
    )
    return surface_curvature_execute(params, execution)


__all__ = [
    "SURFACE_CURVATURE_METADATA",
    "SurfaceCurvatureOutputs",
    "SurfaceCurvatureParameters",
    "surface_curvature",
    "surface_curvature_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

SET_SPACING_METADATA = Metadata(
    id="5a66a083de7d100e80817b6862541b3b2eb2b1ed.boutiques",
    name="SetSpacing",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


SetSpacingParameters = typing.TypedDict('SetSpacingParameters', {
    "__STYX_TYPE__": typing.Literal["SetSpacing"],
    "dimension": int,
    "input_file": InputPathType,
    "output_file": str,
    "spacing": list[float],
})


def dyn_cargs(
    t: str,
) -> typing.Any:
    """
    Get build cargs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build cargs function.
    """
    return {
        "SetSpacing": set_spacing_cargs,
    }.get(t)


def dyn_outputs(
    t: str,
) -> typing.Any:
    """
    Get build outputs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build outputs function.
    """
    return {
        "SetSpacing": set_spacing_outputs,
    }.get(t)


class SetSpacingOutputs(typing.NamedTuple):
    """
    Output object returned when calling `set_spacing(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_image: OutputPathType
    """The output image with the specified spacing."""


def set_spacing_params(
    dimension: int,
    input_file: InputPathType,
    output_file: str,
    spacing: list[float],
) -> SetSpacingParameters:
    """
    Build parameters.
    
    Args:
        dimension: The dimensionality of the image (e.g., 2 or 3).
        input_file: The input image file in HDR format.
        output_file: The output image file in NII format.
        spacing: Spacing values for each dimension. Requires SpacingX,\
            SpacingY, and optionally SpacingZ.
    Returns:
        Parameter dictionary
    """
    params = {
        "__STYXTYPE__": "SetSpacing",
        "dimension": dimension,
        "input_file": input_file,
        "output_file": output_file,
        "spacing": spacing,
    }
    return params


def set_spacing_cargs(
    params: SetSpacingParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("SetSpacing")
    cargs.append(str(params.get("dimension")))
    cargs.append(execution.input_file(params.get("input_file")))
    cargs.append(params.get("output_file"))
    cargs.extend(map(str, params.get("spacing")))
    return cargs


def set_spacing_outputs(
    params: SetSpacingParameters,
    execution: Execution,
) -> SetSpacingOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = SetSpacingOutputs(
        root=execution.output_file("."),
        output_image=execution.output_file(params.get("output_file")),
    )
    return ret


def set_spacing_execute(
    params: SetSpacingParameters,
    execution: Execution,
) -> SetSpacingOutputs:
    """
    A tool to set the spacing of an image in each dimension.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        params: The parameters.
        execution: The execution object.
    Returns:
        NamedTuple of outputs (described in `SetSpacingOutputs`).
    """
    params = execution.params(params)
    cargs = set_spacing_cargs(params, execution)
    ret = set_spacing_outputs(params, execution)
    execution.run(cargs)
    return ret


def set_spacing(
    dimension: int,
    input_file: InputPathType,
    output_file: str,
    spacing: list[float],
    runner: Runner | None = None,
) -> SetSpacingOutputs:
    """
    A tool to set the spacing of an image in each dimension.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        dimension: The dimensionality of the image (e.g., 2 or 3).
        input_file: The input image file in HDR format.
        output_file: The output image file in NII format.
        spacing: Spacing values for each dimension. Requires SpacingX,\
            SpacingY, and optionally SpacingZ.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SetSpacingOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SET_SPACING_METADATA)
    params = set_spacing_params(
        dimension=dimension,
        input_file=input_file,
        output_file=output_file,
        spacing=spacing,
    )
    return set_spacing_execute(params, execution)


__all__ = [
    "SET_SPACING_METADATA",
    "SetSpacingOutputs",
    "SetSpacingParameters",
    "set_spacing",
    "set_spacing_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

SIMULATE_DISPLACEMENT_FIELD_METADATA = Metadata(
    id="ca776aa44d13ed564a1e49ff2d3269669eb9067c.boutiques",
    name="SimulateDisplacementField",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


SimulateDisplacementFieldBsplineOptionsParameters = typing.TypedDict('SimulateDisplacementFieldBsplineOptionsParameters', {
    "__STYX_TYPE__": typing.Literal["bspline_options"],
    "number_of_fitting_levels": typing.NotRequired[int | None],
    "number_of_control_points": typing.NotRequired[int | None],
})


SimulateDisplacementFieldExponentialOptionsParameters = typing.TypedDict('SimulateDisplacementFieldExponentialOptionsParameters', {
    "__STYX_TYPE__": typing.Literal["exponential_options"],
    "smoothing_standard_deviation": typing.NotRequired[float | None],
})


SimulateDisplacementFieldParameters = typing.TypedDict('SimulateDisplacementFieldParameters', {
    "__STYX_TYPE__": typing.Literal["SimulateDisplacementField"],
    "image_dimension": int,
    "displacement_field_type": typing.Literal["BSpline", "Exponential"],
    "domain_image": InputPathType,
    "output_field": str,
    "number_of_random_points": typing.NotRequired[int | None],
    "standard_deviation_displacement_field": typing.NotRequired[float | None],
    "enforce_stationary_boundary": typing.NotRequired[int | None],
    "displacement_specific_options": typing.NotRequired[typing.Union[SimulateDisplacementFieldBsplineOptionsParameters, SimulateDisplacementFieldExponentialOptionsParameters] | None],
})


def dyn_cargs(
    t: str,
) -> typing.Any:
    """
    Get build cargs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build cargs function.
    """
    return {
        "SimulateDisplacementField": simulate_displacement_field_cargs,
        "bspline_options": simulate_displacement_field_bspline_options_cargs,
        "exponential_options": simulate_displacement_field_exponential_options_cargs,
    }.get(t)


def dyn_outputs(
    t: str,
) -> typing.Any:
    """
    Get build outputs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build outputs function.
    """
    return {
        "SimulateDisplacementField": simulate_displacement_field_outputs,
    }.get(t)


def simulate_displacement_field_bspline_options_params(
    number_of_fitting_levels: int | None = 4,
    number_of_control_points: int | None = 4,
) -> SimulateDisplacementFieldBsplineOptionsParameters:
    """
    Build parameters.
    
    Args:
        number_of_fitting_levels: Number of fitting levels for BSpline.
        number_of_control_points: Number of control points for BSpline.
    Returns:
        Parameter dictionary
    """
    params = {
        "__STYXTYPE__": "bspline_options",
    }
    if number_of_fitting_levels is not None:
        params["number_of_fitting_levels"] = number_of_fitting_levels
    if number_of_control_points is not None:
        params["number_of_control_points"] = number_of_control_points
    return params


def simulate_displacement_field_bspline_options_cargs(
    params: SimulateDisplacementFieldBsplineOptionsParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    if params.get("number_of_fitting_levels") is not None:
        cargs.append(str(params.get("number_of_fitting_levels")))
    if params.get("number_of_control_points") is not None:
        cargs.append(str(params.get("number_of_control_points")))
    return cargs


def simulate_displacement_field_exponential_options_params(
    smoothing_standard_deviation: float | None = 4,
) -> SimulateDisplacementFieldExponentialOptionsParameters:
    """
    Build parameters.
    
    Args:
        smoothing_standard_deviation: Smoothing standard deviation for\
            Exponential.
    Returns:
        Parameter dictionary
    """
    params = {
        "__STYXTYPE__": "exponential_options",
    }
    if smoothing_standard_deviation is not None:
        params["smoothing_standard_deviation"] = smoothing_standard_deviation
    return params


def simulate_displacement_field_exponential_options_cargs(
    params: SimulateDisplacementFieldExponentialOptionsParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    if params.get("smoothing_standard_deviation") is not None:
        cargs.append(str(params.get("smoothing_standard_deviation")))
    return cargs


class SimulateDisplacementFieldOutputs(typing.NamedTuple):
    """
    Output object returned when calling `simulate_displacement_field(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_displacement_field: OutputPathType
    """The simulated displacement field."""


def simulate_displacement_field_params(
    image_dimension: int,
    displacement_field_type: typing.Literal["BSpline", "Exponential"],
    domain_image: InputPathType,
    output_field: str,
    number_of_random_points: int | None = 1000,
    standard_deviation_displacement_field: float | None = 10,
    enforce_stationary_boundary: int | None = 1,
    displacement_specific_options: typing.Union[SimulateDisplacementFieldBsplineOptionsParameters, SimulateDisplacementFieldExponentialOptionsParameters] | None = None,
) -> SimulateDisplacementFieldParameters:
    """
    Build parameters.
    
    Args:
        image_dimension: Dimensionality of the image.
        displacement_field_type: Type of displacement field to simulate.
        domain_image: Image defining the domain for the displacement field.
        output_field: Path to save the output displacement field.
        number_of_random_points: Number of random points to use in the\
            simulation.
        standard_deviation_displacement_field: Standard deviation for the\
            displacement field.
        enforce_stationary_boundary: Boolean flag indicating whether to enforce\
            stationary boundary.
        displacement_specific_options: Options specific to the type of\
            displacement field simulation.
    Returns:
        Parameter dictionary
    """
    params = {
        "__STYXTYPE__": "SimulateDisplacementField",
        "image_dimension": image_dimension,
        "displacement_field_type": displacement_field_type,
        "domain_image": domain_image,
        "output_field": output_field,
    }
    if number_of_random_points is not None:
        params["number_of_random_points"] = number_of_random_points
    if standard_deviation_displacement_field is not None:
        params["standard_deviation_displacement_field"] = standard_deviation_displacement_field
    if enforce_stationary_boundary is not None:
        params["enforce_stationary_boundary"] = enforce_stationary_boundary
    if displacement_specific_options is not None:
        params["displacement_specific_options"] = displacement_specific_options
    return params


def simulate_displacement_field_cargs(
    params: SimulateDisplacementFieldParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("SimulateDisplacementField")
    cargs.append(str(params.get("image_dimension")))
    cargs.append(params.get("displacement_field_type"))
    cargs.append(execution.input_file(params.get("domain_image")))
    cargs.append(params.get("output_field"))
    if params.get("number_of_random_points") is not None:
        cargs.append(str(params.get("number_of_random_points")))
    if params.get("standard_deviation_displacement_field") is not None:
        cargs.append(str(params.get("standard_deviation_displacement_field")))
    if params.get("enforce_stationary_boundary") is not None:
        cargs.append(str(params.get("enforce_stationary_boundary")))
    if params.get("displacement_specific_options") is not None:
        cargs.extend(dyn_cargs(params.get("displacement_specific_options")["__STYXTYPE__"])(params.get("displacement_specific_options"), execution))
    return cargs


def simulate_displacement_field_outputs(
    params: SimulateDisplacementFieldParameters,
    execution: Execution,
) -> SimulateDisplacementFieldOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = SimulateDisplacementFieldOutputs(
        root=execution.output_file("."),
        output_displacement_field=execution.output_file(params.get("output_field")),
    )
    return ret


def simulate_displacement_field_execute(
    params: SimulateDisplacementFieldParameters,
    execution: Execution,
) -> SimulateDisplacementFieldOutputs:
    """
    Simulate displacement fields using various methods such as BSpline or
    Exponential.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        params: The parameters.
        execution: The execution object.
    Returns:
        NamedTuple of outputs (described in `SimulateDisplacementFieldOutputs`).
    """
    params = execution.params(params)
    cargs = simulate_displacement_field_cargs(params, execution)
    ret = simulate_displacement_field_outputs(params, execution)
    execution.run(cargs)
    return ret


def simulate_displacement_field(
    image_dimension: int,
    displacement_field_type: typing.Literal["BSpline", "Exponential"],
    domain_image: InputPathType,
    output_field: str,
    number_of_random_points: int | None = 1000,
    standard_deviation_displacement_field: float | None = 10,
    enforce_stationary_boundary: int | None = 1,
    displacement_specific_options: typing.Union[SimulateDisplacementFieldBsplineOptionsParameters, SimulateDisplacementFieldExponentialOptionsParameters] | None = None,
    runner: Runner | None = None,
) -> SimulateDisplacementFieldOutputs:
    """
    Simulate displacement fields using various methods such as BSpline or
    Exponential.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        image_dimension: Dimensionality of the image.
        displacement_field_type: Type of displacement field to simulate.
        domain_image: Image defining the domain for the displacement field.
        output_field: Path to save the output displacement field.
        number_of_random_points: Number of random points to use in the\
            simulation.
        standard_deviation_displacement_field: Standard deviation for the\
            displacement field.
        enforce_stationary_boundary: Boolean flag indicating whether to enforce\
            stationary boundary.
        displacement_specific_options: Options specific to the type of\
            displacement field simulation.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SimulateDisplacementFieldOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SIMULATE_DISPLACEMENT_FIELD_METADATA)
    params = simulate_displacement_field_params(
        image_dimension=image_dimension,
        displacement_field_type=displacement_field_type,
        domain_image=domain_image,
        output_field=output_field,
        number_of_random_points=number_of_random_points,
        standard_deviation_displacement_field=standard_deviation_displacement_field,
        enforce_stationary_boundary=enforce_stationary_boundary,
        displacement_specific_options=displacement_specific_options,
    )
    return simulate_displacement_field_execute(params, execution)


__all__ = [
    "SIMULATE_DISPLACEMENT_FIELD_METADATA",
    "SimulateDisplacementFieldBsplineOptionsParameters",
    "SimulateDisplacementFieldExponentialOptionsParameters",
    "SimulateDisplacementFieldOutputs",
    "SimulateDisplacementFieldParameters",
    "simulate_displacement_field",
    "simulate_displacement_field_bspline_options_params",
    "simulate_displacement_field_exponential_options_params",
    "simulate_displacement_field_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

ANTS_TRANSFORM_INFO_METADATA = Metadata(
    id="db110d69e8361c7a0293d1d70937a09c146e535a.boutiques",
    name="antsTransformInfo",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


AntsTransformInfoParameters = typing.TypedDict('AntsTransformInfoParameters', {
    "__STYX_TYPE__": typing.Literal["antsTransformInfo"],
    "transform_file": InputPathType,
})


def dyn_cargs(
    t: str,
) -> typing.Any:
    """
    Get build cargs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build cargs function.
    """
    return {
        "antsTransformInfo": ants_transform_info_cargs,
    }.get(t)


def dyn_outputs(
    t: str,
) -> typing.Any:
    """
    Get build outputs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build outputs function.
    """
    return {
        "antsTransformInfo": ants_transform_info_outputs,
    }.get(t)


class AntsTransformInfoOutputs(typing.NamedTuple):
    """
    Output object returned when calling `ants_transform_info(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_info: OutputPathType
    """Information of the provided transform file."""


def ants_transform_info_params(
    transform_file: InputPathType,
) -> AntsTransformInfoParameters:
    """
    Build parameters.
    
    Args:
        transform_file: The transform file to read. Supported formats include\
            HDF5, MINC, Matlab, and Txt.
    Returns:
        Parameter dictionary
    """
    params = {
        "__STYXTYPE__": "antsTransformInfo",
        "transform_file": transform_file,
    }
    return params


def ants_transform_info_cargs(
    params: AntsTransformInfoParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("antsTransformInfo")
    cargs.extend([
        "--file",
        execution.input_file(params.get("transform_file"))
    ])
    return cargs


def ants_transform_info_outputs(
    params: AntsTransformInfoParameters,
    execution: Execution,
) -> AntsTransformInfoOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = AntsTransformInfoOutputs(
        root=execution.output_file("."),
        output_info=execution.output_file("transform_info.txt"),
    )
    return ret


def ants_transform_info_execute(
    params: AntsTransformInfoParameters,
    execution: Execution,
) -> AntsTransformInfoOutputs:
    """
    Provide information about an ITK transform file.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        params: The parameters.
        execution: The execution object.
    Returns:
        NamedTuple of outputs (described in `AntsTransformInfoOutputs`).
    """
    params = execution.params(params)
    cargs = ants_transform_info_cargs(params, execution)
    ret = ants_transform_info_outputs(params, execution)
    execution.run(cargs)
    return ret


def ants_transform_info(
    transform_file: InputPathType,
    runner: Runner | None = None,
) -> AntsTransformInfoOutputs:
    """
    Provide information about an ITK transform file.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        transform_file: The transform file to read. Supported formats include\
            HDF5, MINC, Matlab, and Txt.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AntsTransformInfoOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ANTS_TRANSFORM_INFO_METADATA)
    params = ants_transform_info_params(
        transform_file=transform_file,
    )
    return ants_transform_info_execute(params, execution)


__all__ = [
    "ANTS_TRANSFORM_INFO_METADATA",
    "AntsTransformInfoOutputs",
    "AntsTransformInfoParameters",
    "ants_transform_info",
    "ants_transform_info_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

WARP_TENSOR_IMAGE_MULTI_TRANSFORM_METADATA = Metadata(
    id="14d19d5d0cd63cddc6a5dbd0cf982ba44c0b6d8b.boutiques",
    name="WarpTensorImageMultiTransform",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


WarpTensorImageMultiTransformParameters = typing.TypedDict('WarpTensorImageMultiTransformParameters', {
    "__STYX_TYPE__": typing.Literal["WarpTensorImageMultiTransform"],
    "image_dimension": int,
    "moving_image": InputPathType,
    "output_image": str,
    "reference_image": typing.NotRequired[InputPathType | None],
    "tightest_bounding_box": bool,
    "reslice_by_header": bool,
    "use_nearest_neighbor": bool,
    "transforms": list[str],
})


def dyn_cargs(
    t: str,
) -> typing.Any:
    """
    Get build cargs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build cargs function.
    """
    return {
        "WarpTensorImageMultiTransform": warp_tensor_image_multi_transform_cargs,
    }.get(t)


def dyn_outputs(
    t: str,
) -> typing.Any:
    """
    Get build outputs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build outputs function.
    """
    return {
        "WarpTensorImageMultiTransform": warp_tensor_image_multi_transform_outputs,
    }.get(t)


class WarpTensorImageMultiTransformOutputs(typing.NamedTuple):
    """
    Output object returned when calling `warp_tensor_image_multi_transform(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_image_file: OutputPathType
    """The resultant transformed output image."""


def warp_tensor_image_multi_transform_params(
    image_dimension: int,
    moving_image: InputPathType,
    output_image: str,
    transforms: list[str],
    reference_image: InputPathType | None = None,
    tightest_bounding_box: bool = False,
    reslice_by_header: bool = False,
    use_nearest_neighbor: bool = False,
) -> WarpTensorImageMultiTransformParameters:
    """
    Build parameters.
    
    Args:
        image_dimension: Dimensionality of the image (e.g., 2D or 3D).
        moving_image: The moving image that will be transformed.
        output_image: Path for saving the transformed output image.
        transforms: List of transformations to apply, which can include\
            deformation fields or affine transforms.
        reference_image: Reference image for reslicing or defining the\
            transformation domain.
        tightest_bounding_box: Compute the tightest bounding box using all\
            affine transformations.
        reslice_by_header: Use the orientation matrix and origin encoded in the\
            image file header for reslicing.
        use_nearest_neighbor: Use Nearest Neighbor Interpolator for the\
            transformation.
    Returns:
        Parameter dictionary
    """
    params = {
        "__STYXTYPE__": "WarpTensorImageMultiTransform",
        "image_dimension": image_dimension,
        "moving_image": moving_image,
        "output_image": output_image,
        "tightest_bounding_box": tightest_bounding_box,
        "reslice_by_header": reslice_by_header,
        "use_nearest_neighbor": use_nearest_neighbor,
        "transforms": transforms,
    }
    if reference_image is not None:
        params["reference_image"] = reference_image
    return params


def warp_tensor_image_multi_transform_cargs(
    params: WarpTensorImageMultiTransformParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("WarpImageMultiTransform")
    cargs.append(str(params.get("image_dimension")))
    cargs.append(execution.input_file(params.get("moving_image")))
    cargs.append(params.get("output_image"))
    if params.get("reference_image") is not None:
        cargs.extend([
            "-R",
            execution.input_file(params.get("reference_image"))
        ])
    if params.get("tightest_bounding_box"):
        cargs.append("--tightest-bounding-box")
    if params.get("reslice_by_header"):
        cargs.append("--reslice-by-header")
    if params.get("use_nearest_neighbor"):
        cargs.append("--use-NN")
    cargs.extend(params.get("transforms"))
    return cargs


def warp_tensor_image_multi_transform_outputs(
    params: WarpTensorImageMultiTransformParameters,
    execution: Execution,
) -> WarpTensorImageMultiTransformOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = WarpTensorImageMultiTransformOutputs(
        root=execution.output_file("."),
        output_image_file=execution.output_file(params.get("output_image")),
    )
    return ret


def warp_tensor_image_multi_transform_execute(
    params: WarpTensorImageMultiTransformParameters,
    execution: Execution,
) -> WarpTensorImageMultiTransformOutputs:
    """
    WarpImageMultiTransform is used to apply transformations including affine and
    deformation fields to an image, supporting various interpolation techniques,
    image header reslicing, and compatibility with ANTS-generated transformations.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        params: The parameters.
        execution: The execution object.
    Returns:
        NamedTuple of outputs (described in `WarpTensorImageMultiTransformOutputs`).
    """
    params = execution.params(params)
    cargs = warp_tensor_image_multi_transform_cargs(params, execution)
    ret = warp_tensor_image_multi_transform_outputs(params, execution)
    execution.run(cargs)
    return ret


def warp_tensor_image_multi_transform(
    image_dimension: int,
    moving_image: InputPathType,
    output_image: str,
    transforms: list[str],
    reference_image: InputPathType | None = None,
    tightest_bounding_box: bool = False,
    reslice_by_header: bool = False,
    use_nearest_neighbor: bool = False,
    runner: Runner | None = None,
) -> WarpTensorImageMultiTransformOutputs:
    """
    WarpImageMultiTransform is used to apply transformations including affine and
    deformation fields to an image, supporting various interpolation techniques,
    image header reslicing, and compatibility with ANTS-generated transformations.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        image_dimension: Dimensionality of the image (e.g., 2D or 3D).
        moving_image: The moving image that will be transformed.
        output_image: Path for saving the transformed output image.
        transforms: List of transformations to apply, which can include\
            deformation fields or affine transforms.
        reference_image: Reference image for reslicing or defining the\
            transformation domain.
        tightest_bounding_box: Compute the tightest bounding box using all\
            affine transformations.
        reslice_by_header: Use the orientation matrix and origin encoded in the\
            image file header for reslicing.
        use_nearest_neighbor: Use Nearest Neighbor Interpolator for the\
            transformation.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `WarpTensorImageMultiTransformOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(WARP_TENSOR_IMAGE_MULTI_TRANSFORM_METADATA)
    params = warp_tensor_image_multi_transform_params(
        image_dimension=image_dimension,
        moving_image=moving_image,
        output_image=output_image,
        reference_image=reference_image,
        tightest_bounding_box=tightest_bounding_box,
        reslice_by_header=reslice_by_header,
        use_nearest_neighbor=use_nearest_neighbor,
        transforms=transforms,
    )
    return warp_tensor_image_multi_transform_execute(params, execution)


__all__ = [
    "WARP_TENSOR_IMAGE_MULTI_TRANSFORM_METADATA",
    "WarpTensorImageMultiTransformOutputs",
    "WarpTensorImageMultiTransformParameters",
    "warp_tensor_image_multi_transform",
    "warp_tensor_image_multi_transform_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

SIMPLE_SYN_REGISTRATION_METADATA = Metadata(
    id="8bdec8bc3a221887858c098adc61e63838dc3139.boutiques",
    name="simpleSynRegistration",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


SimpleSynRegistrationParameters = typing.TypedDict('SimpleSynRegistrationParameters', {
    "__STYX_TYPE__": typing.Literal["simpleSynRegistration"],
    "fixed_image": InputPathType,
    "moving_image": InputPathType,
    "initial_transform": str,
    "output_prefix": str,
})


def dyn_cargs(
    t: str,
) -> typing.Any:
    """
    Get build cargs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build cargs function.
    """
    return {
        "simpleSynRegistration": simple_syn_registration_cargs,
    }.get(t)


def dyn_outputs(
    t: str,
) -> typing.Any:
    """
    Get build outputs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build outputs function.
    """
    return {
        "simpleSynRegistration": simple_syn_registration_outputs,
    }.get(t)


class SimpleSynRegistrationOutputs(typing.NamedTuple):
    """
    Output object returned when calling `simple_syn_registration(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    registered_image: OutputPathType
    """The output registered image."""
    transform_matrix: OutputPathType
    """The output transformation matrix."""


def simple_syn_registration_params(
    fixed_image: InputPathType,
    moving_image: InputPathType,
    initial_transform: str,
    output_prefix: str,
) -> SimpleSynRegistrationParameters:
    """
    Build parameters.
    
    Args:
        fixed_image: The fixed image for registration.
        moving_image: The moving image to be registered.
        initial_transform: The initial transform for registration.
        output_prefix: Prefix for the output file name without any extension.
    Returns:
        Parameter dictionary
    """
    params = {
        "__STYXTYPE__": "simpleSynRegistration",
        "fixed_image": fixed_image,
        "moving_image": moving_image,
        "initial_transform": initial_transform,
        "output_prefix": output_prefix,
    }
    return params


def simple_syn_registration_cargs(
    params: SimpleSynRegistrationParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("simpleSynRegistration")
    cargs.append(execution.input_file(params.get("fixed_image")) + ",")
    cargs.append(execution.input_file(params.get("moving_image")) + ",")
    cargs.append(params.get("initial_transform") + ",")
    cargs.append(params.get("output_prefix"))
    return cargs


def simple_syn_registration_outputs(
    params: SimpleSynRegistrationParameters,
    execution: Execution,
) -> SimpleSynRegistrationOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = SimpleSynRegistrationOutputs(
        root=execution.output_file("."),
        registered_image=execution.output_file(params.get("output_prefix") + "Registered.nii.gz"),
        transform_matrix=execution.output_file(params.get("output_prefix") + "Transform.mat"),
    )
    return ret


def simple_syn_registration_execute(
    params: SimpleSynRegistrationParameters,
    execution: Execution,
) -> SimpleSynRegistrationOutputs:
    """
    A simple SyN registration tool.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        params: The parameters.
        execution: The execution object.
    Returns:
        NamedTuple of outputs (described in `SimpleSynRegistrationOutputs`).
    """
    params = execution.params(params)
    cargs = simple_syn_registration_cargs(params, execution)
    ret = simple_syn_registration_outputs(params, execution)
    execution.run(cargs)
    return ret


def simple_syn_registration(
    fixed_image: InputPathType,
    moving_image: InputPathType,
    initial_transform: str,
    output_prefix: str,
    runner: Runner | None = None,
) -> SimpleSynRegistrationOutputs:
    """
    A simple SyN registration tool.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        fixed_image: The fixed image for registration.
        moving_image: The moving image to be registered.
        initial_transform: The initial transform for registration.
        output_prefix: Prefix for the output file name without any extension.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SimpleSynRegistrationOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SIMPLE_SYN_REGISTRATION_METADATA)
    params = simple_syn_registration_params(
        fixed_image=fixed_image,
        moving_image=moving_image,
        initial_transform=initial_transform,
        output_prefix=output_prefix,
    )
    return simple_syn_registration_execute(params, execution)


__all__ = [
    "SIMPLE_SYN_REGISTRATION_METADATA",
    "SimpleSynRegistrationOutputs",
    "SimpleSynRegistrationParameters",
    "simple_syn_registration",
    "simple_syn_registration_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

IMAGE_INTENSITY_STATISTICS_METADATA = Metadata(
    id="ba7ab9e8e494076bff274459f3f86dfd1563d5d9.boutiques",
    name="ImageIntensityStatistics",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


ImageIntensityStatisticsParameters = typing.TypedDict('ImageIntensityStatisticsParameters', {
    "__STYX_TYPE__": typing.Literal["ImageIntensityStatistics"],
    "image_dimension": int,
    "input_image": InputPathType,
    "label_image": typing.NotRequired[InputPathType | None],
})


def dyn_cargs(
    t: str,
) -> typing.Any:
    """
    Get build cargs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build cargs function.
    """
    return {
        "ImageIntensityStatistics": image_intensity_statistics_cargs,
    }.get(t)


def dyn_outputs(
    t: str,
) -> typing.Any:
    """
    Get build outputs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build outputs function.
    """
    return {
        "ImageIntensityStatistics": image_intensity_statistics_outputs,
    }.get(t)


class ImageIntensityStatisticsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `image_intensity_statistics(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    intensity_statistics: OutputPathType
    """The output file containing intensity statistics."""


def image_intensity_statistics_params(
    image_dimension: int,
    input_image: InputPathType,
    label_image: InputPathType | None = None,
) -> ImageIntensityStatisticsParameters:
    """
    Build parameters.
    
    Args:
        image_dimension: The dimensionality of the image (e.g., 2D, 3D).
        input_image: The input image for which intensity statistics will be\
            computed.
        label_image: An optional label image which defines regions of interest.
    Returns:
        Parameter dictionary
    """
    params = {
        "__STYXTYPE__": "ImageIntensityStatistics",
        "image_dimension": image_dimension,
        "input_image": input_image,
    }
    if label_image is not None:
        params["label_image"] = label_image
    return params


def image_intensity_statistics_cargs(
    params: ImageIntensityStatisticsParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("ImageIntensityStatistics")
    cargs.append(str(params.get("image_dimension")))
    cargs.append(execution.input_file(params.get("input_image")))
    if params.get("label_image") is not None:
        cargs.append(execution.input_file(params.get("label_image")))
    return cargs


def image_intensity_statistics_outputs(
    params: ImageIntensityStatisticsParameters,
    execution: Execution,
) -> ImageIntensityStatisticsOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = ImageIntensityStatisticsOutputs(
        root=execution.output_file("."),
        intensity_statistics=execution.output_file("intensity_statistics.txt"),
    )
    return ret


def image_intensity_statistics_execute(
    params: ImageIntensityStatisticsParameters,
    execution: Execution,
) -> ImageIntensityStatisticsOutputs:
    """
    This tool computes intensity statistics of an input image, optionally given a
    label image.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        params: The parameters.
        execution: The execution object.
    Returns:
        NamedTuple of outputs (described in `ImageIntensityStatisticsOutputs`).
    """
    params = execution.params(params)
    cargs = image_intensity_statistics_cargs(params, execution)
    ret = image_intensity_statistics_outputs(params, execution)
    execution.run(cargs)
    return ret


def image_intensity_statistics(
    image_dimension: int,
    input_image: InputPathType,
    label_image: InputPathType | None = None,
    runner: Runner | None = None,
) -> ImageIntensityStatisticsOutputs:
    """
    This tool computes intensity statistics of an input image, optionally given a
    label image.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        image_dimension: The dimensionality of the image (e.g., 2D, 3D).
        input_image: The input image for which intensity statistics will be\
            computed.
        label_image: An optional label image which defines regions of interest.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ImageIntensityStatisticsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(IMAGE_INTENSITY_STATISTICS_METADATA)
    params = image_intensity_statistics_params(
        image_dimension=image_dimension,
        input_image=input_image,
        label_image=label_image,
    )
    return image_intensity_statistics_execute(params, execution)


__all__ = [
    "IMAGE_INTENSITY_STATISTICS_METADATA",
    "ImageIntensityStatisticsOutputs",
    "ImageIntensityStatisticsParameters",
    "image_intensity_statistics",
    "image_intensity_statistics_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

THRESHOLD_IMAGE_METADATA = Metadata(
    id="8cf8b0c4869168dc7cd4d8ddd7703d636b4075fc.boutiques",
    name="ThresholdImage",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


ThresholdImageParameters = typing.TypedDict('ThresholdImageParameters', {
    "__STYX_TYPE__": typing.Literal["ThresholdImage"],
    "image_dimension": int,
    "image_in": InputPathType,
    "out_image": str,
    "threshlo": typing.NotRequired[float | None],
    "threshhi": typing.NotRequired[float | None],
    "inside_value": typing.NotRequired[float | None],
    "outside_value": typing.NotRequired[float | None],
    "otsu_number_of_thresholds": typing.NotRequired[float | None],
    "kmeans_number_of_thresholds": typing.NotRequired[float | None],
    "mask_image": typing.NotRequired[InputPathType | None],
})


def dyn_cargs(
    t: str,
) -> typing.Any:
    """
    Get build cargs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build cargs function.
    """
    return {
        "ThresholdImage": threshold_image_cargs,
    }.get(t)


def dyn_outputs(
    t: str,
) -> typing.Any:
    """
    Get build outputs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build outputs function.
    """
    return {
        "ThresholdImage": threshold_image_outputs,
    }.get(t)


class ThresholdImageOutputs(typing.NamedTuple):
    """
    Output object returned when calling `threshold_image(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_image: OutputPathType
    """The resulting image after thresholding."""


def threshold_image_params(
    image_dimension: int,
    image_in: InputPathType,
    out_image: str,
    threshlo: float | None = None,
    threshhi: float | None = None,
    inside_value: float | None = None,
    outside_value: float | None = None,
    otsu_number_of_thresholds: float | None = None,
    kmeans_number_of_thresholds: float | None = None,
    mask_image: InputPathType | None = None,
) -> ThresholdImageParameters:
    """
    Build parameters.
    
    Args:
        image_dimension: The dimension of the input image.
        image_in: The input image file to be thresholded.
        out_image: The output image file after thresholding.
        threshlo: The lower threshold value for fixed thresholding.
        threshhi: The upper threshold value for fixed thresholding.
        inside_value: The pixel value to be used inside the threshold range.
        outside_value: The pixel value to be used outside the threshold range.
        otsu_number_of_thresholds: Number of thresholds to use when applying\
            the Otsu method.
        kmeans_number_of_thresholds: Number of thresholds to use when applying\
            the K-means method.
        mask_image: Optional mask image for the thresholding operation.
    Returns:
        Parameter dictionary
    """
    params = {
        "__STYXTYPE__": "ThresholdImage",
        "image_dimension": image_dimension,
        "image_in": image_in,
        "out_image": out_image,
    }
    if threshlo is not None:
        params["threshlo"] = threshlo
    if threshhi is not None:
        params["threshhi"] = threshhi
    if inside_value is not None:
        params["inside_value"] = inside_value
    if outside_value is not None:
        params["outside_value"] = outside_value
    if otsu_number_of_thresholds is not None:
        params["otsu_number_of_thresholds"] = otsu_number_of_thresholds
    if kmeans_number_of_thresholds is not None:
        params["kmeans_number_of_thresholds"] = kmeans_number_of_thresholds
    if mask_image is not None:
        params["mask_image"] = mask_image
    return params


def threshold_image_cargs(
    params: ThresholdImageParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("ThresholdImage")
    cargs.append(str(params.get("image_dimension")))
    cargs.append(execution.input_file(params.get("image_in")))
    cargs.append(params.get("out_image"))
    if params.get("threshlo") is not None:
        cargs.append(str(params.get("threshlo")))
    if params.get("threshhi") is not None:
        cargs.append(str(params.get("threshhi")))
    if params.get("inside_value") is not None:
        cargs.append(str(params.get("inside_value")))
    if params.get("outside_value") is not None:
        cargs.append(str(params.get("outside_value")))
    if params.get("otsu_number_of_thresholds") is not None:
        cargs.append(str(params.get("otsu_number_of_thresholds")))
    if params.get("kmeans_number_of_thresholds") is not None:
        cargs.append(str(params.get("kmeans_number_of_thresholds")))
    if params.get("mask_image") is not None:
        cargs.append(execution.input_file(params.get("mask_image")))
    return cargs


def threshold_image_outputs(
    params: ThresholdImageParameters,
    execution: Execution,
) -> ThresholdImageOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = ThresholdImageOutputs(
        root=execution.output_file("."),
        output_image=execution.output_file(params.get("out_image")),
    )
    return ret


def threshold_image_execute(
    params: ThresholdImageParameters,
    execution: Execution,
) -> ThresholdImageOutputs:
    """
    Image thresholding utility that applies different thresholding techniques to an
    input image. It can use fixed thresholds, Otsu method, or K-means for
    thresholding.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        params: The parameters.
        execution: The execution object.
    Returns:
        NamedTuple of outputs (described in `ThresholdImageOutputs`).
    """
    params = execution.params(params)
    cargs = threshold_image_cargs(params, execution)
    ret = threshold_image_outputs(params, execution)
    execution.run(cargs)
    return ret


def threshold_image(
    image_dimension: int,
    image_in: InputPathType,
    out_image: str,
    threshlo: float | None = None,
    threshhi: float | None = None,
    inside_value: float | None = None,
    outside_value: float | None = None,
    otsu_number_of_thresholds: float | None = None,
    kmeans_number_of_thresholds: float | None = None,
    mask_image: InputPathType | None = None,
    runner: Runner | None = None,
) -> ThresholdImageOutputs:
    """
    Image thresholding utility that applies different thresholding techniques to an
    input image. It can use fixed thresholds, Otsu method, or K-means for
    thresholding.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        image_dimension: The dimension of the input image.
        image_in: The input image file to be thresholded.
        out_image: The output image file after thresholding.
        threshlo: The lower threshold value for fixed thresholding.
        threshhi: The upper threshold value for fixed thresholding.
        inside_value: The pixel value to be used inside the threshold range.
        outside_value: The pixel value to be used outside the threshold range.
        otsu_number_of_thresholds: Number of thresholds to use when applying\
            the Otsu method.
        kmeans_number_of_thresholds: Number of thresholds to use when applying\
            the K-means method.
        mask_image: Optional mask image for the thresholding operation.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ThresholdImageOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(THRESHOLD_IMAGE_METADATA)
    params = threshold_image_params(
        image_dimension=image_dimension,
        image_in=image_in,
        out_image=out_image,
        threshlo=threshlo,
        threshhi=threshhi,
        inside_value=inside_value,
        outside_value=outside_value,
        otsu_number_of_thresholds=otsu_number_of_thresholds,
        kmeans_number_of_thresholds=kmeans_number_of_thresholds,
        mask_image=mask_image,
    )
    return threshold_image_execute(params, execution)


__all__ = [
    "THRESHOLD_IMAGE_METADATA",
    "ThresholdImageOutputs",
    "ThresholdImageParameters",
    "threshold_image",
    "threshold_image_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

ANTS_BRAIN_EXTRACTION_SH_METADATA = Metadata(
    id="1f8c451b98f93c105aed231bb6898634ea958829.boutiques",
    name="antsBrainExtraction.sh",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


AntsBrainExtractionShParameters = typing.TypedDict('AntsBrainExtractionShParameters', {
    "__STYX_TYPE__": typing.Literal["antsBrainExtraction.sh"],
    "image_dimension": int,
    "anatomical_image": InputPathType,
    "template": InputPathType,
    "probability_mask": InputPathType,
    "tissue_classification": typing.NotRequired[str | None],
    "brain_extraction_registration_mask": typing.NotRequired[InputPathType | None],
    "keep_temporary_files": bool,
    "single_floating_point_precision": bool,
    "initial_moving_transform": typing.NotRequired[InputPathType | None],
    "rotation_search_params": typing.NotRequired[str | None],
    "image_file_suffix": typing.NotRequired[str | None],
    "translation_search_params": typing.NotRequired[str | None],
    "random_seeding": bool,
    "debug_mode": bool,
    "output_prefix": typing.NotRequired[str | None],
})


def dyn_cargs(
    t: str,
) -> typing.Any:
    """
    Get build cargs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build cargs function.
    """
    return {
        "antsBrainExtraction.sh": ants_brain_extraction_sh_cargs,
    }.get(t)


def dyn_outputs(
    t: str,
) -> typing.Any:
    """
    Get build outputs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build outputs function.
    """
    return {
        "antsBrainExtraction.sh": ants_brain_extraction_sh_outputs,
    }.get(t)


class AntsBrainExtractionShOutputs(typing.NamedTuple):
    """
    Output object returned when calling `ants_brain_extraction_sh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    brain_extracted_image: OutputPathType | None
    """Brain extracted image"""
    brain_mask: OutputPathType | None
    """Brain mask"""
    brain_probability_mask: OutputPathType | None
    """Brain probability mask"""


def ants_brain_extraction_sh_params(
    anatomical_image: InputPathType,
    template: InputPathType,
    probability_mask: InputPathType,
    image_dimension: int = 3,
    tissue_classification: str | None = None,
    brain_extraction_registration_mask: InputPathType | None = None,
    keep_temporary_files: bool = False,
    single_floating_point_precision: bool = False,
    initial_moving_transform: InputPathType | None = None,
    rotation_search_params: str | None = None,
    image_file_suffix: str | None = None,
    translation_search_params: str | None = None,
    random_seeding: bool = False,
    debug_mode: bool = False,
    output_prefix: str | None = "output",
) -> AntsBrainExtractionShParameters:
    """
    Build parameters.
    
    Args:
        anatomical_image: Anatomical image (Structural image, typically T1).
        template: Brain extraction template (Anatomical template).
        probability_mask: Brain extraction probability mask.
        image_dimension: Image dimension (2 or 3).
        tissue_classification: Tissue classification.
        brain_extraction_registration_mask: Brain extraction registration mask.
        keep_temporary_files: Keep temporary files.
        single_floating_point_precision: Use single floating point precision.
        initial_moving_transform: Initial moving transform.
        rotation_search_params: Rotation search parameters.
        image_file_suffix: Image file suffix.
        translation_search_params: Translation search parameters.
        random_seeding: Use random seeding.
        debug_mode: Test / debug mode.
        output_prefix: Output prefix.
    Returns:
        Parameter dictionary
    """
    params = {
        "__STYXTYPE__": "antsBrainExtraction.sh",
        "image_dimension": image_dimension,
        "anatomical_image": anatomical_image,
        "template": template,
        "probability_mask": probability_mask,
        "keep_temporary_files": keep_temporary_files,
        "single_floating_point_precision": single_floating_point_precision,
        "random_seeding": random_seeding,
        "debug_mode": debug_mode,
    }
    if tissue_classification is not None:
        params["tissue_classification"] = tissue_classification
    if brain_extraction_registration_mask is not None:
        params["brain_extraction_registration_mask"] = brain_extraction_registration_mask
    if initial_moving_transform is not None:
        params["initial_moving_transform"] = initial_moving_transform
    if rotation_search_params is not None:
        params["rotation_search_params"] = rotation_search_params
    if image_file_suffix is not None:
        params["image_file_suffix"] = image_file_suffix
    if translation_search_params is not None:
        params["translation_search_params"] = translation_search_params
    if output_prefix is not None:
        params["output_prefix"] = output_prefix
    return params


def ants_brain_extraction_sh_cargs(
    params: AntsBrainExtractionShParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("antsBrainExtraction.sh")
    cargs.extend([
        "-d",
        str(params.get("image_dimension"))
    ])
    cargs.extend([
        "-a",
        execution.input_file(params.get("anatomical_image"))
    ])
    cargs.extend([
        "-e",
        execution.input_file(params.get("template"))
    ])
    cargs.extend([
        "-m",
        execution.input_file(params.get("probability_mask"))
    ])
    if params.get("tissue_classification") is not None:
        cargs.extend([
            "-c",
            params.get("tissue_classification")
        ])
    if params.get("brain_extraction_registration_mask") is not None:
        cargs.extend([
            "-f",
            execution.input_file(params.get("brain_extraction_registration_mask"))
        ])
    if params.get("keep_temporary_files"):
        cargs.append("-k")
    if params.get("single_floating_point_precision"):
        cargs.append("-q")
    if params.get("initial_moving_transform") is not None:
        cargs.extend([
            "-r",
            execution.input_file(params.get("initial_moving_transform"))
        ])
    if params.get("rotation_search_params") is not None:
        cargs.extend([
            "-R",
            params.get("rotation_search_params")
        ])
    if params.get("image_file_suffix") is not None:
        cargs.extend([
            "-s",
            params.get("image_file_suffix")
        ])
    if params.get("translation_search_params") is not None:
        cargs.extend([
            "-T",
            params.get("translation_search_params")
        ])
    if params.get("random_seeding"):
        cargs.append("-u")
    if params.get("debug_mode"):
        cargs.append("-z")
    if params.get("output_prefix") is not None:
        cargs.extend([
            "-o",
            params.get("output_prefix")
        ])
    return cargs


def ants_brain_extraction_sh_outputs(
    params: AntsBrainExtractionShParameters,
    execution: Execution,
) -> AntsBrainExtractionShOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = AntsBrainExtractionShOutputs(
        root=execution.output_file("."),
        brain_extracted_image=execution.output_file(params.get("output_prefix") + "_BrainExtractionBrain.nii.gz") if (params.get("output_prefix") is not None) else None,
        brain_mask=execution.output_file(params.get("output_prefix") + "_BrainExtractionMask.nii.gz") if (params.get("output_prefix") is not None) else None,
        brain_probability_mask=execution.output_file(params.get("output_prefix") + "_BrainExtractionPrior0GenericAffine.mat") if (params.get("output_prefix") is not None) else None,
    )
    return ret


def ants_brain_extraction_sh_execute(
    params: AntsBrainExtractionShParameters,
    execution: Execution,
) -> AntsBrainExtractionShOutputs:
    """
    antsBrainExtraction.sh performs template-based brain extraction.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        params: The parameters.
        execution: The execution object.
    Returns:
        NamedTuple of outputs (described in `AntsBrainExtractionShOutputs`).
    """
    params = execution.params(params)
    cargs = ants_brain_extraction_sh_cargs(params, execution)
    ret = ants_brain_extraction_sh_outputs(params, execution)
    execution.run(cargs)
    return ret


def ants_brain_extraction_sh(
    anatomical_image: InputPathType,
    template: InputPathType,
    probability_mask: InputPathType,
    image_dimension: int = 3,
    tissue_classification: str | None = None,
    brain_extraction_registration_mask: InputPathType | None = None,
    keep_temporary_files: bool = False,
    single_floating_point_precision: bool = False,
    initial_moving_transform: InputPathType | None = None,
    rotation_search_params: str | None = None,
    image_file_suffix: str | None = None,
    translation_search_params: str | None = None,
    random_seeding: bool = False,
    debug_mode: bool = False,
    output_prefix: str | None = "output",
    runner: Runner | None = None,
) -> AntsBrainExtractionShOutputs:
    """
    antsBrainExtraction.sh performs template-based brain extraction.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        anatomical_image: Anatomical image (Structural image, typically T1).
        template: Brain extraction template (Anatomical template).
        probability_mask: Brain extraction probability mask.
        image_dimension: Image dimension (2 or 3).
        tissue_classification: Tissue classification.
        brain_extraction_registration_mask: Brain extraction registration mask.
        keep_temporary_files: Keep temporary files.
        single_floating_point_precision: Use single floating point precision.
        initial_moving_transform: Initial moving transform.
        rotation_search_params: Rotation search parameters.
        image_file_suffix: Image file suffix.
        translation_search_params: Translation search parameters.
        random_seeding: Use random seeding.
        debug_mode: Test / debug mode.
        output_prefix: Output prefix.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AntsBrainExtractionShOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ANTS_BRAIN_EXTRACTION_SH_METADATA)
    params = ants_brain_extraction_sh_params(
        image_dimension=image_dimension,
        anatomical_image=anatomical_image,
        template=template,
        probability_mask=probability_mask,
        tissue_classification=tissue_classification,
        brain_extraction_registration_mask=brain_extraction_registration_mask,
        keep_temporary_files=keep_temporary_files,
        single_floating_point_precision=single_floating_point_precision,
        initial_moving_transform=initial_moving_transform,
        rotation_search_params=rotation_search_params,
        image_file_suffix=image_file_suffix,
        translation_search_params=translation_search_params,
        random_seeding=random_seeding,
        debug_mode=debug_mode,
        output_prefix=output_prefix,
    )
    return ants_brain_extraction_sh_execute(params, execution)


__all__ = [
    "ANTS_BRAIN_EXTRACTION_SH_METADATA",
    "AntsBrainExtractionShOutputs",
    "AntsBrainExtractionShParameters",
    "ants_brain_extraction_sh",
    "ants_brain_extraction_sh_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

ANTS_INTRODUCTION_SH_METADATA = Metadata(
    id="ea6433a22b9e7d78a34c893edf721a839a07cf99.boutiques",
    name="antsIntroduction.sh",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


AntsIntroductionShParameters = typing.TypedDict('AntsIntroductionShParameters', {
    "__STYX_TYPE__": typing.Literal["antsIntroduction.sh"],
    "image_dimension": typing.Literal[2, 3],
    "reference_image": InputPathType,
    "input_image": InputPathType,
    "force": typing.NotRequired[typing.Literal[0, 1] | None],
    "labels_in_fixed_image_space": typing.NotRequired[str | None],
    "max_iterations": typing.NotRequired[int | None],
    "n4_bias_field_correction": typing.NotRequired[typing.Literal[0, 1] | None],
    "outprefix": typing.NotRequired[str | None],
    "quality_check": typing.NotRequired[typing.Literal[0, 1] | None],
    "similarity_metric": typing.NotRequired[str | None],
    "transformation_model": typing.NotRequired[str | None],
})


def dyn_cargs(
    t: str,
) -> typing.Any:
    """
    Get build cargs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build cargs function.
    """
    return {
        "antsIntroduction.sh": ants_introduction_sh_cargs,
    }.get(t)


def dyn_outputs(
    t: str,
) -> typing.Any:
    """
    Get build outputs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build outputs function.
    """
    return {
    }.get(t)


class AntsIntroductionShOutputs(typing.NamedTuple):
    """
    Output object returned when calling `ants_introduction_sh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def ants_introduction_sh_params(
    image_dimension: typing.Literal[2, 3],
    reference_image: InputPathType,
    input_image: InputPathType,
    force: typing.Literal[0, 1] | None = 1,
    labels_in_fixed_image_space: str | None = None,
    max_iterations: int | None = None,
    n4_bias_field_correction: typing.Literal[0, 1] | None = 0,
    outprefix: str | None = None,
    quality_check: typing.Literal[0, 1] | None = 0,
    similarity_metric: str | None = None,
    transformation_model: str | None = None,
) -> AntsIntroductionShParameters:
    """
    Build parameters.
    
    Args:
        image_dimension: Image dimension for registration: 2 or 3.
        reference_image: Reference image for registration.
        input_image: Input image to be registered.
        force: Force script to proceed even if headers may be incompatible.
        labels_in_fixed_image_space: Labels in fixed image space to deform to\
            moving image.
        max_iterations: Maximum number of iterations.
        n4_bias_field_correction: N4 Bias Field Correction of moving image: 0\
            for off, 1 for on.
        outprefix: A prefix that is prepended to all output files.
        quality_check: Perform a Quality Check (QC) of the result: 0 for off, 1\
            for on.
        similarity_metric: Type of similarity metric used for registration.
        transformation_model: Type of transformation model used for\
            registration.
    Returns:
        Parameter dictionary
    """
    params = {
        "__STYXTYPE__": "antsIntroduction.sh",
        "image_dimension": image_dimension,
        "reference_image": reference_image,
        "input_image": input_image,
    }
    if force is not None:
        params["force"] = force
    if labels_in_fixed_image_space is not None:
        params["labels_in_fixed_image_space"] = labels_in_fixed_image_space
    if max_iterations is not None:
        params["max_iterations"] = max_iterations
    if n4_bias_field_correction is not None:
        params["n4_bias_field_correction"] = n4_bias_field_correction
    if outprefix is not None:
        params["outprefix"] = outprefix
    if quality_check is not None:
        params["quality_check"] = quality_check
    if similarity_metric is not None:
        params["similarity_metric"] = similarity_metric
    if transformation_model is not None:
        params["transformation_model"] = transformation_model
    return params


def ants_introduction_sh_cargs(
    params: AntsIntroductionShParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("antsIntroduction.sh")
    cargs.extend([
        "-d",
        str(params.get("image_dimension"))
    ])
    cargs.extend([
        "-r",
        execution.input_file(params.get("reference_image"))
    ])
    cargs.extend([
        "-i",
        execution.input_file(params.get("input_image"))
    ])
    if params.get("force") is not None:
        cargs.extend([
            "-f",
            str(params.get("force"))
        ])
    if params.get("labels_in_fixed_image_space") is not None:
        cargs.extend([
            "-l",
            params.get("labels_in_fixed_image_space")
        ])
    if params.get("max_iterations") is not None:
        cargs.extend([
            "-m",
            str(params.get("max_iterations"))
        ])
    if params.get("n4_bias_field_correction") is not None:
        cargs.extend([
            "-n",
            str(params.get("n4_bias_field_correction"))
        ])
    if params.get("outprefix") is not None:
        cargs.extend([
            "-o",
            params.get("outprefix")
        ])
    if params.get("quality_check") is not None:
        cargs.extend([
            "-q",
            str(params.get("quality_check"))
        ])
    if params.get("similarity_metric") is not None:
        cargs.extend([
            "-s",
            params.get("similarity_metric")
        ])
    if params.get("transformation_model") is not None:
        cargs.extend([
            "-t",
            params.get("transformation_model")
        ])
    return cargs


def ants_introduction_sh_outputs(
    params: AntsIntroductionShParameters,
    execution: Execution,
) -> AntsIntroductionShOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = AntsIntroductionShOutputs(
        root=execution.output_file("."),
    )
    return ret


def ants_introduction_sh_execute(
    params: AntsIntroductionShParameters,
    execution: Execution,
) -> AntsIntroductionShOutputs:
    """
    Script for registration using ANTS with compulsory and optional arguments.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        params: The parameters.
        execution: The execution object.
    Returns:
        NamedTuple of outputs (described in `AntsIntroductionShOutputs`).
    """
    params = execution.params(params)
    cargs = ants_introduction_sh_cargs(params, execution)
    ret = ants_introduction_sh_outputs(params, execution)
    execution.run(cargs)
    return ret


def ants_introduction_sh(
    image_dimension: typing.Literal[2, 3],
    reference_image: InputPathType,
    input_image: InputPathType,
    force: typing.Literal[0, 1] | None = 1,
    labels_in_fixed_image_space: str | None = None,
    max_iterations: int | None = None,
    n4_bias_field_correction: typing.Literal[0, 1] | None = 0,
    outprefix: str | None = None,
    quality_check: typing.Literal[0, 1] | None = 0,
    similarity_metric: str | None = None,
    transformation_model: str | None = None,
    runner: Runner | None = None,
) -> AntsIntroductionShOutputs:
    """
    Script for registration using ANTS with compulsory and optional arguments.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        image_dimension: Image dimension for registration: 2 or 3.
        reference_image: Reference image for registration.
        input_image: Input image to be registered.
        force: Force script to proceed even if headers may be incompatible.
        labels_in_fixed_image_space: Labels in fixed image space to deform to\
            moving image.
        max_iterations: Maximum number of iterations.
        n4_bias_field_correction: N4 Bias Field Correction of moving image: 0\
            for off, 1 for on.
        outprefix: A prefix that is prepended to all output files.
        quality_check: Perform a Quality Check (QC) of the result: 0 for off, 1\
            for on.
        similarity_metric: Type of similarity metric used for registration.
        transformation_model: Type of transformation model used for\
            registration.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AntsIntroductionShOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ANTS_INTRODUCTION_SH_METADATA)
    params = ants_introduction_sh_params(
        image_dimension=image_dimension,
        reference_image=reference_image,
        input_image=input_image,
        force=force,
        labels_in_fixed_image_space=labels_in_fixed_image_space,
        max_iterations=max_iterations,
        n4_bias_field_correction=n4_bias_field_correction,
        outprefix=outprefix,
        quality_check=quality_check,
        similarity_metric=similarity_metric,
        transformation_model=transformation_model,
    )
    return ants_introduction_sh_execute(params, execution)


__all__ = [
    "ANTS_INTRODUCTION_SH_METADATA",
    "AntsIntroductionShOutputs",
    "AntsIntroductionShParameters",
    "ants_introduction_sh",
    "ants_introduction_sh_params",
]
